searchData={"items":[{"type":"module","title":"Fledex","doc":"This module should provide some simple macros that allow to define the\nled strip and to update it. The code you would write (in livebook) would\nlook something like the following:\niex> use Fledex\niex> led_strip do\n        live_loop :john, send_config: %{offset: counter}, delay_config: counter do\n          config = %{\n            num_leds: 50,\n            reversed: true\n          }\n\n          leds(50)\n            |> func(:rainbow, config)\n        end\n    end","ref":"Fledex.html"},{"type":"function","title":"Fledex.fledex_loaded/0","doc":"This function should not be used. It's only here for tests and can be removed\nany any point in time. It only returns `:ok`","ref":"Fledex.html#fledex_loaded/0"},{"type":"macro","title":"Fledex.led_strip/3","doc":"This introduces a new led_strip. Probably we only have a single\n  led strip and then the default name (the module name) will be used.","ref":"Fledex.html#led_strip/3"},{"type":"macro","title":"Fledex.live_loop/3","doc":"This introduces a new `live_loop` (animation) that will be played over\n  and over again until it is changed. Therefore we we give it a name to\n  know whether it changes","ref":"Fledex.html#live_loop/3"},{"type":"module","title":"Fledex.Application","doc":"","ref":"Fledex.Application.html"},{"type":"function","title":"Fledex.Application.start/2","doc":"","ref":"Fledex.Application.html#start/2"},{"type":"module","title":"Fledex.LedAnimationManager","doc":"","ref":"Fledex.LedAnimationManager.html"},{"type":"function","title":"Fledex.LedAnimationManager.get_info/1","doc":"","ref":"Fledex.LedAnimationManager.html#get_info/1"},{"type":"function","title":"Fledex.LedAnimationManager.register_animations/2","doc":"","ref":"Fledex.LedAnimationManager.html#register_animations/2"},{"type":"function","title":"Fledex.LedAnimationManager.register_strip/2","doc":"","ref":"Fledex.LedAnimationManager.html#register_strip/2"},{"type":"function","title":"Fledex.LedAnimationManager.start_link/0","doc":"","ref":"Fledex.LedAnimationManager.html#start_link/0"},{"type":"function","title":"Fledex.LedAnimationManager.unregister_strip/1","doc":"","ref":"Fledex.LedAnimationManager.html#unregister_strip/1"},{"type":"module","title":"Fledex.LedAnimator","doc":"The client often wants to run some animations. This can of course be done by repeatedly updating the `Leds` definitions and calling\n`Leds.send()` to send it to the driver.\nThis often results in constructs like the following:application\n```\n  Enum.each(1..10, fn index ->\n  Leds\n    |> led_definition function(index)\n    |> Leds.send(config)\n    Process.sleep(600)\n  end)\n ```\n This creates a loop over some led definition, sends it to the LED strip and then\n waits for a while to do the next step.\n The index can be used for either influencing the led definition function,\n or the offset of the strip and thereby influencing the animation.\n\nThis approach is not really good, because of the following drawbacks:\n* it is difficult to update the animation while it's running,\n   because it would require to interrupt the loop\n* the sending to the LED strip can not be optimized, except by knowing\n   at which update frequency the driver is updating the strip. Of course it would be\n   possible for a client to figure this out, but who would do that?\n\n The idea of this module is to take care of those concerns by implementing a GenServer that\n runs the loop, but can be updated in-between.\n\n From the above example it can be seen that two things can be updated:\n * The led_definition_function and\n * The send config (even though we will have to implement that as a function too due to the handling of the index)\n\n Note: the time is not something that can be specified, since the animator will be triggered by\n `LedsDriver` in it's update frequency. Thus to implement some wait pattern, the trigger counter (or some\n other timer logic) should be used\n\n Both of them can be set by defining an appropriate function and setting and resetting a reference at will","ref":"Fledex.LedAnimator.html"},{"type":"function","title":"Fledex.LedAnimator.config/3","doc":"","ref":"Fledex.LedAnimator.html#config/3"},{"type":"function","title":"Fledex.LedAnimator.default_def_func/1","doc":"","ref":"Fledex.LedAnimator.html#default_def_func/1"},{"type":"function","title":"Fledex.LedAnimator.default_send_config_func/1","doc":"","ref":"Fledex.LedAnimator.html#default_send_config_func/1"},{"type":"function","title":"Fledex.LedAnimator.shutdown/2","doc":"","ref":"Fledex.LedAnimator.html#shutdown/2"},{"type":"function","title":"Fledex.LedAnimator.start_link/3","doc":"","ref":"Fledex.LedAnimator.html#start_link/3"},{"type":"function","title":"Fledex.LedAnimator.update_config/2","doc":"","ref":"Fledex.LedAnimator.html#update_config/2"},{"type":"type","title":"Fledex.LedAnimator.ledAnimatorConfig/0","doc":"","ref":"Fledex.LedAnimator.html#t:ledAnimatorConfig/0"},{"type":"type","title":"Fledex.LedAnimator.ledAnimatorState/0","doc":"","ref":"Fledex.LedAnimator.html#t:ledAnimatorState/0"},{"type":"module","title":"Fledex.Leds","doc":"","ref":"Fledex.Leds.html"},{"type":"function","title":"Fledex.Leds.convert_to_leds_structure/2","doc":"","ref":"Fledex.Leds.html#convert_to_leds_structure/2"},{"type":"function","title":"Fledex.Leds.func/3","doc":"","ref":"Fledex.Leds.html#func/3"},{"type":"function","title":"Fledex.Leds.get_light/2","doc":"","ref":"Fledex.Leds.html#get_light/2"},{"type":"function","title":"Fledex.Leds.gradient/2","doc":"","ref":"Fledex.Leds.html#gradient/2"},{"type":"function","title":"Fledex.Leds.leds/0","doc":"","ref":"Fledex.Leds.html#leds/0"},{"type":"function","title":"Fledex.Leds.leds/1","doc":"","ref":"Fledex.Leds.html#leds/1"},{"type":"function","title":"Fledex.Leds.leds/2","doc":"","ref":"Fledex.Leds.html#leds/2"},{"type":"function","title":"Fledex.Leds.leds/3","doc":"","ref":"Fledex.Leds.html#leds/3"},{"type":"function","title":"Fledex.Leds.leds/4","doc":"","ref":"Fledex.Leds.html#leds/4"},{"type":"function","title":"Fledex.Leds.light/2","doc":"","ref":"Fledex.Leds.html#light/2"},{"type":"function","title":"Fledex.Leds.light/3","doc":"offset is 1 indexed. Offset needs to be > 0 if it's bigger than the count\nthen the led will be stored, but ignored","ref":"Fledex.Leds.html#light/3"},{"type":"function","title":"Fledex.Leds.light/4","doc":"","ref":"Fledex.Leds.html#light/4"},{"type":"function","title":"Fledex.Leds.rainbow/2","doc":"","ref":"Fledex.Leds.html#rainbow/2"},{"type":"function","title":"Fledex.Leds.repeat/2","doc":"","ref":"Fledex.Leds.html#repeat/2"},{"type":"function","title":"Fledex.Leds.rotate/3","doc":"","ref":"Fledex.Leds.html#rotate/3"},{"type":"function","title":"Fledex.Leds.send/2","doc":"","ref":"Fledex.Leds.html#send/2"},{"type":"function","title":"Fledex.Leds.set_driver_info/3","doc":"","ref":"Fledex.Leds.html#set_driver_info/3"},{"type":"function","title":"Fledex.Leds.to_binary/1","doc":"","ref":"Fledex.Leds.html#to_binary/1"},{"type":"function","title":"Fledex.Leds.to_list/1","doc":"","ref":"Fledex.Leds.html#to_list/1"},{"type":"type","title":"Fledex.Leds.t/0","doc":"","ref":"Fledex.Leds.html#t:t/0"},{"type":"module","title":"Fledex.Leds.Functions","doc":"","ref":"Fledex.Leds.Functions.html"},{"type":"function","title":"Fledex.Leds.Functions.create_gradient_rgb/3","doc":"","ref":"Fledex.Leds.Functions.html#create_gradient_rgb/3"},{"type":"function","title":"Fledex.Leds.Functions.create_rainbow_circular_hsv/3","doc":"","ref":"Fledex.Leds.Functions.html#create_rainbow_circular_hsv/3"},{"type":"function","title":"Fledex.Leds.Functions.create_rainbow_circular_rgb/3","doc":"","ref":"Fledex.Leds.Functions.html#create_rainbow_circular_rgb/3"},{"type":"function","title":"Fledex.Leds.Functions.hsv2rgb/3","doc":"","ref":"Fledex.Leds.Functions.html#hsv2rgb/3"},{"type":"module","title":"Fledex.LedsDriver","doc":"This module defines a GenServer that manages the LED strip (be it a real one with the\nSpiDriver or a virtual one with e.g. the KinoDriver). Usually you only want to start\none server, even though it is possible to start several.\nThe LedsDriver will take several Leds definitions and merge them together to be displayed\non a single LED strip\nThe role the LedsDriver plays is similar to the one a window server  plays on a normal computer","ref":"Fledex.LedsDriver.html"},{"type":"function","title":"Fledex.LedsDriver.apply_merge_strategy/2","doc":"","ref":"Fledex.LedsDriver.html#apply_merge_strategy/2"},{"type":"function","title":"Fledex.LedsDriver.change_config/3","doc":"","ref":"Fledex.LedsDriver.html#change_config/3"},{"type":"function","title":"Fledex.LedsDriver.define_namespace/2","doc":"","ref":"Fledex.LedsDriver.html#define_namespace/2"},{"type":"function","title":"Fledex.LedsDriver.drop_namespace/2","doc":"","ref":"Fledex.LedsDriver.html#drop_namespace/2"},{"type":"function","title":"Fledex.LedsDriver.exist_namespace/2","doc":"","ref":"Fledex.LedsDriver.html#exist_namespace/2"},{"type":"function","title":"Fledex.LedsDriver.extend/2","doc":"","ref":"Fledex.LedsDriver.html#extend/2"},{"type":"function","title":"Fledex.LedsDriver.get_leds/1","doc":"","ref":"Fledex.LedsDriver.html#get_leds/1"},{"type":"function","title":"Fledex.LedsDriver.init_state/2","doc":"","ref":"Fledex.LedsDriver.html#init_state/2"},{"type":"function","title":"Fledex.LedsDriver.match_length/1","doc":"","ref":"Fledex.LedsDriver.html#match_length/1"},{"type":"function","title":"Fledex.LedsDriver.merge_leds/2","doc":"","ref":"Fledex.LedsDriver.html#merge_leds/2"},{"type":"function","title":"Fledex.LedsDriver.merge_namespaces/2","doc":"","ref":"Fledex.LedsDriver.html#merge_namespaces/2"},{"type":"function","title":"Fledex.LedsDriver.merge_pixels/2","doc":"","ref":"Fledex.LedsDriver.html#merge_pixels/2"},{"type":"function","title":"Fledex.LedsDriver.reinit_drivers/1","doc":"","ref":"Fledex.LedsDriver.html#reinit_drivers/1"},{"type":"function","title":"Fledex.LedsDriver.set_leds/3","doc":"","ref":"Fledex.LedsDriver.html#set_leds/3"},{"type":"function","title":"Fledex.LedsDriver.start_link/2","doc":"","ref":"Fledex.LedsDriver.html#start_link/2"},{"type":"function","title":"Fledex.LedsDriver.transfer_data/1","doc":"","ref":"Fledex.LedsDriver.html#transfer_data/1"},{"type":"type","title":"Fledex.LedsDriver.t/0","doc":"","ref":"Fledex.LedsDriver.html#t:t/0"},{"type":"module","title":"Fledex.Utils.PubSub","doc":"","ref":"Fledex.Utils.PubSub.html"},{"type":"function","title":"Fledex.Utils.PubSub.broadcast/3","doc":"","ref":"Fledex.Utils.PubSub.html#broadcast/3"},{"type":"function","title":"Fledex.Utils.PubSub.subscribe/2","doc":"","ref":"Fledex.Utils.PubSub.html#subscribe/2"},{"type":"function","title":"Fledex.Utils.PubSub.unsubscribe/2","doc":"","ref":"Fledex.Utils.PubSub.html#unsubscribe/2"},{"type":"behaviour","title":"Fledex.LedStripDriver.Driver","doc":"","ref":"Fledex.LedStripDriver.Driver.html"},{"type":"callback","title":"Fledex.LedStripDriver.Driver.init/1","doc":"","ref":"Fledex.LedStripDriver.Driver.html#c:init/1"},{"type":"function","title":"Fledex.LedStripDriver.Driver.init/2","doc":"","ref":"Fledex.LedStripDriver.Driver.html#init/2"},{"type":"function","title":"Fledex.LedStripDriver.Driver.reinit/1","doc":"","ref":"Fledex.LedStripDriver.Driver.html#reinit/1"},{"type":"callback","title":"Fledex.LedStripDriver.Driver.reinit/1","doc":"","ref":"Fledex.LedStripDriver.Driver.html#c:reinit/1"},{"type":"function","title":"Fledex.LedStripDriver.Driver.terminate/2","doc":"","ref":"Fledex.LedStripDriver.Driver.html#terminate/2"},{"type":"callback","title":"Fledex.LedStripDriver.Driver.terminate/2","doc":"","ref":"Fledex.LedStripDriver.Driver.html#c:terminate/2"},{"type":"function","title":"Fledex.LedStripDriver.Driver.transfer/2","doc":"","ref":"Fledex.LedStripDriver.Driver.html#transfer/2"},{"type":"callback","title":"Fledex.LedStripDriver.Driver.transfer/3","doc":"","ref":"Fledex.LedStripDriver.Driver.html#c:transfer/3"},{"type":"module","title":"Fledex.LedStripDriver.KinoDriver","doc":"","ref":"Fledex.LedStripDriver.KinoDriver.html"},{"type":"module","title":"Fledex.LedStripDriver.LoggerDriver","doc":"This is a dummy implementation of the LedStripDriver that dumps\n  the binaries to IO. This can be useful if you want to run\n  some tests without real hardware.\n  The real implementatin probably opens a channel (if not already open)\n  to the bus (like SPI) sends the data to the bus.\n\n  Note: this module is allowed to store information in the state\n  (like the channel it has oppened), so that we don't have open/close it\n  all the time. Cleanup should happen in the terminate function","ref":"Fledex.LedStripDriver.LoggerDriver.html"},{"type":"module","title":"Fledex.LedStripDriver.NullDriver","doc":"This is a dummy implementation of the LedStripDriver that doesn't do\n  anything (similar to a /dev/null device). This can be useful if you\n  want to run some tests without getting any output or sending it to hardware.","ref":"Fledex.LedStripDriver.NullDriver.html"},{"type":"module","title":"Fledex.LedStripDriver.SpiDriver","doc":"","ref":"Fledex.LedStripDriver.SpiDriver.html"},{"type":"function","title":"Fledex.LedStripDriver.SpiDriver.open_spi/1","doc":"","ref":"Fledex.LedStripDriver.SpiDriver.html#open_spi/1"},{"type":"module","title":"Fledex.Color.Conversion.Approximate","doc":"","ref":"Fledex.Color.Conversion.Approximate.html"},{"type":"function","title":"Fledex.Color.Conversion.Approximate.rgb2hsv/1","doc":"","ref":"Fledex.Color.Conversion.Approximate.html#rgb2hsv/1"},{"type":"module","title":"Fledex.Color.Conversion.Rainbow","doc":"","ref":"Fledex.Color.Conversion.Rainbow.html"},{"type":"function","title":"Fledex.Color.Conversion.Rainbow.hsv2rgb/2","doc":"","ref":"Fledex.Color.Conversion.Rainbow.html#hsv2rgb/2"},{"type":"module","title":"Fledex.Color.Conversion.Raw","doc":"","ref":"Fledex.Color.Conversion.Raw.html"},{"type":"function","title":"Fledex.Color.Conversion.Raw.hsv2rgb/2","doc":"","ref":"Fledex.Color.Conversion.Raw.html#hsv2rgb/2"},{"type":"function","title":"Fledex.Color.Conversion.Raw.set_colors/4","doc":"","ref":"Fledex.Color.Conversion.Raw.html#set_colors/4"},{"type":"module","title":"Fledex.Color.Conversion.Spectrum","doc":"","ref":"Fledex.Color.Conversion.Spectrum.html"},{"type":"function","title":"Fledex.Color.Conversion.Spectrum.hsv2rgb/2","doc":"","ref":"Fledex.Color.Conversion.Spectrum.html#hsv2rgb/2"},{"type":"module","title":"Fledex.Color.Correction","doc":"","ref":"Fledex.Color.Correction.html"},{"type":"function","title":"Fledex.Color.Correction.apply_rgb_correction/2","doc":"","ref":"Fledex.Color.Correction.html#apply_rgb_correction/2"},{"type":"function","title":"Fledex.Color.Correction.calculate_color_correction/3","doc":"","ref":"Fledex.Color.Correction.html#calculate_color_correction/3"},{"type":"function","title":"Fledex.Color.Correction.color_correction_g2/1","doc":"","ref":"Fledex.Color.Correction.html#color_correction_g2/1"},{"type":"function","title":"Fledex.Color.Correction.color_correction_none/1","doc":"","ref":"Fledex.Color.Correction.html#color_correction_none/1"},{"type":"function","title":"Fledex.Color.Correction.define_correction/3","doc":"","ref":"Fledex.Color.Correction.html#define_correction/3"},{"type":"function","title":"Fledex.Color.Correction.no_color_correction/0","doc":"","ref":"Fledex.Color.Correction.html#no_color_correction/0"},{"type":"module","title":"Fledex.Color.Correction.Color","doc":"","ref":"Fledex.Color.Correction.Color.html"},{"type":"function","title":"Fledex.Color.Correction.Color.typical_8mm_pixel/0","doc":"","ref":"Fledex.Color.Correction.Color.html#typical_8mm_pixel/0"},{"type":"function","title":"Fledex.Color.Correction.Color.typical_led_strip/0","doc":"","ref":"Fledex.Color.Correction.Color.html#typical_led_strip/0"},{"type":"function","title":"Fledex.Color.Correction.Color.typical_pixel/0","doc":"","ref":"Fledex.Color.Correction.Color.html#typical_pixel/0"},{"type":"function","title":"Fledex.Color.Correction.Color.typical_smd5050/0","doc":"","ref":"Fledex.Color.Correction.Color.html#typical_smd5050/0"},{"type":"function","title":"Fledex.Color.Correction.Color.uncorrected_color/0","doc":"","ref":"Fledex.Color.Correction.Color.html#uncorrected_color/0"},{"type":"module","title":"Fledex.Color.Correction.Temperature","doc":"","ref":"Fledex.Color.Correction.Temperature.html"},{"type":"function","title":"Fledex.Color.Correction.Temperature.black_light_fluorescent/0","doc":"","ref":"Fledex.Color.Correction.Temperature.html#black_light_fluorescent/0"},{"type":"function","title":"Fledex.Color.Correction.Temperature.candle/0","doc":"","ref":"Fledex.Color.Correction.Temperature.html#candle/0"},{"type":"function","title":"Fledex.Color.Correction.Temperature.carbon_arc/0","doc":"","ref":"Fledex.Color.Correction.Temperature.html#carbon_arc/0"},{"type":"function","title":"Fledex.Color.Correction.Temperature.clear_blue_sky/0","doc":"","ref":"Fledex.Color.Correction.Temperature.html#clear_blue_sky/0"},{"type":"function","title":"Fledex.Color.Correction.Temperature.cool_white_fluorescent/0","doc":"","ref":"Fledex.Color.Correction.Temperature.html#cool_white_fluorescent/0"},{"type":"function","title":"Fledex.Color.Correction.Temperature.direct_sunlight/0","doc":"","ref":"Fledex.Color.Correction.Temperature.html#direct_sunlight/0"},{"type":"function","title":"Fledex.Color.Correction.Temperature.full_spectrum_fluorescent/0","doc":"","ref":"Fledex.Color.Correction.Temperature.html#full_spectrum_fluorescent/0"},{"type":"function","title":"Fledex.Color.Correction.Temperature.grow_light_fluorescent/0","doc":"","ref":"Fledex.Color.Correction.Temperature.html#grow_light_fluorescent/0"},{"type":"function","title":"Fledex.Color.Correction.Temperature.halogen/0","doc":"","ref":"Fledex.Color.Correction.Temperature.html#halogen/0"},{"type":"function","title":"Fledex.Color.Correction.Temperature.high_noon_sun/0","doc":"","ref":"Fledex.Color.Correction.Temperature.html#high_noon_sun/0"},{"type":"function","title":"Fledex.Color.Correction.Temperature.high_pressure_sodium/0","doc":"","ref":"Fledex.Color.Correction.Temperature.html#high_pressure_sodium/0"},{"type":"function","title":"Fledex.Color.Correction.Temperature.mercury_vapor/0","doc":"","ref":"Fledex.Color.Correction.Temperature.html#mercury_vapor/0"},{"type":"function","title":"Fledex.Color.Correction.Temperature.metal_halide/0","doc":"","ref":"Fledex.Color.Correction.Temperature.html#metal_halide/0"},{"type":"function","title":"Fledex.Color.Correction.Temperature.overcast_sky/0","doc":"","ref":"Fledex.Color.Correction.Temperature.html#overcast_sky/0"},{"type":"function","title":"Fledex.Color.Correction.Temperature.sodium_vapor/0","doc":"","ref":"Fledex.Color.Correction.Temperature.html#sodium_vapor/0"},{"type":"function","title":"Fledex.Color.Correction.Temperature.standard_fluorescent/0","doc":"","ref":"Fledex.Color.Correction.Temperature.html#standard_fluorescent/0"},{"type":"function","title":"Fledex.Color.Correction.Temperature.tungsten_40w/0","doc":"","ref":"Fledex.Color.Correction.Temperature.html#tungsten_40w/0"},{"type":"function","title":"Fledex.Color.Correction.Temperature.tungsten_100w/0","doc":"","ref":"Fledex.Color.Correction.Temperature.html#tungsten_100w/0"},{"type":"function","title":"Fledex.Color.Correction.Temperature.uncorrected_temperature/0","doc":"","ref":"Fledex.Color.Correction.Temperature.html#uncorrected_temperature/0"},{"type":"function","title":"Fledex.Color.Correction.Temperature.warm_fluorescent/0","doc":"","ref":"Fledex.Color.Correction.Temperature.html#warm_fluorescent/0"},{"type":"module","title":"Fledex.Color.LoadUtils","doc":"","ref":"Fledex.Color.LoadUtils.html"},{"type":"function","title":"Fledex.Color.LoadUtils.load_color_file/1","doc":"","ref":"Fledex.Color.LoadUtils.html#load_color_file/1"},{"type":"function","title":"Fledex.Color.LoadUtils.names_file/0","doc":"","ref":"Fledex.Color.LoadUtils.html#names_file/0"},{"type":"function","title":"Fledex.Color.LoadUtils.parse_line/2","doc":"","ref":"Fledex.Color.LoadUtils.html#parse_line/2"},{"type":"module","title":"Fledex.Color.Names","doc":"","ref":"Fledex.Color.Names.html"},{"type":"function","title":"Fledex.Color.Names.absolute_zero/0","doc":"","ref":"Fledex.Color.Names.html#absolute_zero/0"},{"type":"function","title":"Fledex.Color.Names.acid_green/0","doc":"","ref":"Fledex.Color.Names.html#acid_green/0"},{"type":"function","title":"Fledex.Color.Names.aero/0","doc":"","ref":"Fledex.Color.Names.html#aero/0"},{"type":"function","title":"Fledex.Color.Names.african_violet/0","doc":"","ref":"Fledex.Color.Names.html#african_violet/0"},{"type":"function","title":"Fledex.Color.Names.air_superiority_blue/0","doc":"","ref":"Fledex.Color.Names.html#air_superiority_blue/0"},{"type":"function","title":"Fledex.Color.Names.alice_blue/0","doc":"","ref":"Fledex.Color.Names.html#alice_blue/0"},{"type":"function","title":"Fledex.Color.Names.alizarin/0","doc":"","ref":"Fledex.Color.Names.html#alizarin/0"},{"type":"function","title":"Fledex.Color.Names.alloy_orange/0","doc":"","ref":"Fledex.Color.Names.html#alloy_orange/0"},{"type":"function","title":"Fledex.Color.Names.almond/0","doc":"","ref":"Fledex.Color.Names.html#almond/0"},{"type":"function","title":"Fledex.Color.Names.amaranth_deep_purple/0","doc":"","ref":"Fledex.Color.Names.html#amaranth_deep_purple/0"},{"type":"function","title":"Fledex.Color.Names.amaranth_pink/0","doc":"","ref":"Fledex.Color.Names.html#amaranth_pink/0"},{"type":"function","title":"Fledex.Color.Names.amaranth_purple/0","doc":"","ref":"Fledex.Color.Names.html#amaranth_purple/0"},{"type":"function","title":"Fledex.Color.Names.amazon/0","doc":"","ref":"Fledex.Color.Names.html#amazon/0"},{"type":"function","title":"Fledex.Color.Names.amber/0","doc":"","ref":"Fledex.Color.Names.html#amber/0"},{"type":"function","title":"Fledex.Color.Names.amethyst/0","doc":"","ref":"Fledex.Color.Names.html#amethyst/0"},{"type":"function","title":"Fledex.Color.Names.android_green/0","doc":"","ref":"Fledex.Color.Names.html#android_green/0"},{"type":"function","title":"Fledex.Color.Names.antique_brass/0","doc":"","ref":"Fledex.Color.Names.html#antique_brass/0"},{"type":"function","title":"Fledex.Color.Names.antique_bronze/0","doc":"","ref":"Fledex.Color.Names.html#antique_bronze/0"},{"type":"function","title":"Fledex.Color.Names.antique_fuchsia/0","doc":"","ref":"Fledex.Color.Names.html#antique_fuchsia/0"},{"type":"function","title":"Fledex.Color.Names.antique_ruby/0","doc":"","ref":"Fledex.Color.Names.html#antique_ruby/0"},{"type":"function","title":"Fledex.Color.Names.antique_white/0","doc":"","ref":"Fledex.Color.Names.html#antique_white/0"},{"type":"function","title":"Fledex.Color.Names.apricot/0","doc":"","ref":"Fledex.Color.Names.html#apricot/0"},{"type":"function","title":"Fledex.Color.Names.aqua/0","doc":"","ref":"Fledex.Color.Names.html#aqua/0"},{"type":"function","title":"Fledex.Color.Names.aquamarine/0","doc":"","ref":"Fledex.Color.Names.html#aquamarine/0"},{"type":"function","title":"Fledex.Color.Names.arctic_lime/0","doc":"","ref":"Fledex.Color.Names.html#arctic_lime/0"},{"type":"function","title":"Fledex.Color.Names.artichoke_green/0","doc":"","ref":"Fledex.Color.Names.html#artichoke_green/0"},{"type":"function","title":"Fledex.Color.Names.arylide_yellow/0","doc":"","ref":"Fledex.Color.Names.html#arylide_yellow/0"},{"type":"function","title":"Fledex.Color.Names.ash_gray/0","doc":"","ref":"Fledex.Color.Names.html#ash_gray/0"},{"type":"function","title":"Fledex.Color.Names.atomic_tangerine/0","doc":"","ref":"Fledex.Color.Names.html#atomic_tangerine/0"},{"type":"function","title":"Fledex.Color.Names.aureolin/0","doc":"","ref":"Fledex.Color.Names.html#aureolin/0"},{"type":"function","title":"Fledex.Color.Names.azure/0","doc":"","ref":"Fledex.Color.Names.html#azure/0"},{"type":"function","title":"Fledex.Color.Names.azure_x11_web_color_/0","doc":"","ref":"Fledex.Color.Names.html#azure_x11_web_color_/0"},{"type":"function","title":"Fledex.Color.Names.b_dazzled_blue/0","doc":"","ref":"Fledex.Color.Names.html#b_dazzled_blue/0"},{"type":"function","title":"Fledex.Color.Names.baby_blue/0","doc":"","ref":"Fledex.Color.Names.html#baby_blue/0"},{"type":"function","title":"Fledex.Color.Names.baby_blue_eyes/0","doc":"","ref":"Fledex.Color.Names.html#baby_blue_eyes/0"},{"type":"function","title":"Fledex.Color.Names.baby_pink/0","doc":"","ref":"Fledex.Color.Names.html#baby_pink/0"},{"type":"function","title":"Fledex.Color.Names.baby_powder/0","doc":"","ref":"Fledex.Color.Names.html#baby_powder/0"},{"type":"function","title":"Fledex.Color.Names.baker_miller_pink/0","doc":"","ref":"Fledex.Color.Names.html#baker_miller_pink/0"},{"type":"function","title":"Fledex.Color.Names.banana_mania/0","doc":"","ref":"Fledex.Color.Names.html#banana_mania/0"},{"type":"function","title":"Fledex.Color.Names.barn_red/0","doc":"","ref":"Fledex.Color.Names.html#barn_red/0"},{"type":"function","title":"Fledex.Color.Names.battleship_grey/0","doc":"","ref":"Fledex.Color.Names.html#battleship_grey/0"},{"type":"function","title":"Fledex.Color.Names.beau_blue/0","doc":"","ref":"Fledex.Color.Names.html#beau_blue/0"},{"type":"function","title":"Fledex.Color.Names.beaver/0","doc":"","ref":"Fledex.Color.Names.html#beaver/0"},{"type":"function","title":"Fledex.Color.Names.beige/0","doc":"","ref":"Fledex.Color.Names.html#beige/0"},{"type":"function","title":"Fledex.Color.Names.big_dip_o_ruby/0","doc":"","ref":"Fledex.Color.Names.html#big_dip_o_ruby/0"},{"type":"function","title":"Fledex.Color.Names.bisque/0","doc":"","ref":"Fledex.Color.Names.html#bisque/0"},{"type":"function","title":"Fledex.Color.Names.bistre/0","doc":"","ref":"Fledex.Color.Names.html#bistre/0"},{"type":"function","title":"Fledex.Color.Names.bistre_brown/0","doc":"","ref":"Fledex.Color.Names.html#bistre_brown/0"},{"type":"function","title":"Fledex.Color.Names.bitter_lemon/0","doc":"","ref":"Fledex.Color.Names.html#bitter_lemon/0"},{"type":"function","title":"Fledex.Color.Names.black/0","doc":"","ref":"Fledex.Color.Names.html#black/0"},{"type":"function","title":"Fledex.Color.Names.black_bean/0","doc":"","ref":"Fledex.Color.Names.html#black_bean/0"},{"type":"function","title":"Fledex.Color.Names.black_coral/0","doc":"","ref":"Fledex.Color.Names.html#black_coral/0"},{"type":"function","title":"Fledex.Color.Names.black_olive/0","doc":"","ref":"Fledex.Color.Names.html#black_olive/0"},{"type":"function","title":"Fledex.Color.Names.black_shadows/0","doc":"","ref":"Fledex.Color.Names.html#black_shadows/0"},{"type":"function","title":"Fledex.Color.Names.blanched_almond/0","doc":"","ref":"Fledex.Color.Names.html#blanched_almond/0"},{"type":"function","title":"Fledex.Color.Names.blast_off_bronze/0","doc":"","ref":"Fledex.Color.Names.html#blast_off_bronze/0"},{"type":"function","title":"Fledex.Color.Names.bleu_de_france/0","doc":"","ref":"Fledex.Color.Names.html#bleu_de_france/0"},{"type":"function","title":"Fledex.Color.Names.blizzard_blue/0","doc":"","ref":"Fledex.Color.Names.html#blizzard_blue/0"},{"type":"function","title":"Fledex.Color.Names.blood_red/0","doc":"","ref":"Fledex.Color.Names.html#blood_red/0"},{"type":"function","title":"Fledex.Color.Names.blue/0","doc":"","ref":"Fledex.Color.Names.html#blue/0"},{"type":"function","title":"Fledex.Color.Names.blue_bell/0","doc":"","ref":"Fledex.Color.Names.html#blue_bell/0"},{"type":"function","title":"Fledex.Color.Names.blue_crayola_/0","doc":"","ref":"Fledex.Color.Names.html#blue_crayola_/0"},{"type":"function","title":"Fledex.Color.Names.blue_gray_crayola_/0","doc":"","ref":"Fledex.Color.Names.html#blue_gray_crayola_/0"},{"type":"function","title":"Fledex.Color.Names.blue_jeans/0","doc":"","ref":"Fledex.Color.Names.html#blue_jeans/0"},{"type":"function","title":"Fledex.Color.Names.blue_munsell_/0","doc":"","ref":"Fledex.Color.Names.html#blue_munsell_/0"},{"type":"function","title":"Fledex.Color.Names.blue_ncs_/0","doc":"","ref":"Fledex.Color.Names.html#blue_ncs_/0"},{"type":"function","title":"Fledex.Color.Names.blue_pantone_/0","doc":"","ref":"Fledex.Color.Names.html#blue_pantone_/0"},{"type":"function","title":"Fledex.Color.Names.blue_pigment_/0","doc":"","ref":"Fledex.Color.Names.html#blue_pigment_/0"},{"type":"function","title":"Fledex.Color.Names.blue_sapphire/0","doc":"","ref":"Fledex.Color.Names.html#blue_sapphire/0"},{"type":"function","title":"Fledex.Color.Names.blue_violet/0","doc":"","ref":"Fledex.Color.Names.html#blue_violet/0"},{"type":"function","title":"Fledex.Color.Names.blue_yonder/0","doc":"","ref":"Fledex.Color.Names.html#blue_yonder/0"},{"type":"function","title":"Fledex.Color.Names.bluetiful/0","doc":"","ref":"Fledex.Color.Names.html#bluetiful/0"},{"type":"function","title":"Fledex.Color.Names.blush/0","doc":"","ref":"Fledex.Color.Names.html#blush/0"},{"type":"function","title":"Fledex.Color.Names.bole/0","doc":"","ref":"Fledex.Color.Names.html#bole/0"},{"type":"function","title":"Fledex.Color.Names.bone/0","doc":"","ref":"Fledex.Color.Names.html#bone/0"},{"type":"function","title":"Fledex.Color.Names.brick_red/0","doc":"","ref":"Fledex.Color.Names.html#brick_red/0"},{"type":"function","title":"Fledex.Color.Names.bright_lilac/0","doc":"","ref":"Fledex.Color.Names.html#bright_lilac/0"},{"type":"function","title":"Fledex.Color.Names.bright_yellow_crayola_/0","doc":"","ref":"Fledex.Color.Names.html#bright_yellow_crayola_/0"},{"type":"function","title":"Fledex.Color.Names.bronze/0","doc":"","ref":"Fledex.Color.Names.html#bronze/0"},{"type":"function","title":"Fledex.Color.Names.brown_sugar/0","doc":"","ref":"Fledex.Color.Names.html#brown_sugar/0"},{"type":"function","title":"Fledex.Color.Names.bud_green/0","doc":"","ref":"Fledex.Color.Names.html#bud_green/0"},{"type":"function","title":"Fledex.Color.Names.buff/0","doc":"","ref":"Fledex.Color.Names.html#buff/0"},{"type":"function","title":"Fledex.Color.Names.burgundy/0","doc":"","ref":"Fledex.Color.Names.html#burgundy/0"},{"type":"function","title":"Fledex.Color.Names.burlywood/0","doc":"","ref":"Fledex.Color.Names.html#burlywood/0"},{"type":"function","title":"Fledex.Color.Names.burnished_brown/0","doc":"","ref":"Fledex.Color.Names.html#burnished_brown/0"},{"type":"function","title":"Fledex.Color.Names.burnt_orange/0","doc":"","ref":"Fledex.Color.Names.html#burnt_orange/0"},{"type":"function","title":"Fledex.Color.Names.burnt_sienna/0","doc":"","ref":"Fledex.Color.Names.html#burnt_sienna/0"},{"type":"function","title":"Fledex.Color.Names.burnt_umber/0","doc":"","ref":"Fledex.Color.Names.html#burnt_umber/0"},{"type":"function","title":"Fledex.Color.Names.byzantine/0","doc":"","ref":"Fledex.Color.Names.html#byzantine/0"},{"type":"function","title":"Fledex.Color.Names.byzantium/0","doc":"","ref":"Fledex.Color.Names.html#byzantium/0"},{"type":"function","title":"Fledex.Color.Names.cadet_blue/0","doc":"","ref":"Fledex.Color.Names.html#cadet_blue/0"},{"type":"function","title":"Fledex.Color.Names.cadet_grey/0","doc":"","ref":"Fledex.Color.Names.html#cadet_grey/0"},{"type":"function","title":"Fledex.Color.Names.cadmium_green/0","doc":"","ref":"Fledex.Color.Names.html#cadmium_green/0"},{"type":"function","title":"Fledex.Color.Names.cadmium_orange/0","doc":"","ref":"Fledex.Color.Names.html#cadmium_orange/0"},{"type":"function","title":"Fledex.Color.Names.cafe_au_lait/0","doc":"","ref":"Fledex.Color.Names.html#cafe_au_lait/0"},{"type":"function","title":"Fledex.Color.Names.cafe_noir/0","doc":"","ref":"Fledex.Color.Names.html#cafe_noir/0"},{"type":"function","title":"Fledex.Color.Names.cambridge_blue/0","doc":"","ref":"Fledex.Color.Names.html#cambridge_blue/0"},{"type":"function","title":"Fledex.Color.Names.camel/0","doc":"","ref":"Fledex.Color.Names.html#camel/0"},{"type":"function","title":"Fledex.Color.Names.cameo_pink/0","doc":"","ref":"Fledex.Color.Names.html#cameo_pink/0"},{"type":"function","title":"Fledex.Color.Names.canary/0","doc":"","ref":"Fledex.Color.Names.html#canary/0"},{"type":"function","title":"Fledex.Color.Names.canary_yellow/0","doc":"","ref":"Fledex.Color.Names.html#canary_yellow/0"},{"type":"function","title":"Fledex.Color.Names.candy_pink/0","doc":"","ref":"Fledex.Color.Names.html#candy_pink/0"},{"type":"function","title":"Fledex.Color.Names.cardinal/0","doc":"","ref":"Fledex.Color.Names.html#cardinal/0"},{"type":"function","title":"Fledex.Color.Names.caribbean_green/0","doc":"","ref":"Fledex.Color.Names.html#caribbean_green/0"},{"type":"function","title":"Fledex.Color.Names.carmine/0","doc":"","ref":"Fledex.Color.Names.html#carmine/0"},{"type":"function","title":"Fledex.Color.Names.carmine_m_p_/0","doc":"","ref":"Fledex.Color.Names.html#carmine_m_p_/0"},{"type":"function","title":"Fledex.Color.Names.carnation_pink/0","doc":"","ref":"Fledex.Color.Names.html#carnation_pink/0"},{"type":"function","title":"Fledex.Color.Names.carnelian/0","doc":"","ref":"Fledex.Color.Names.html#carnelian/0"},{"type":"function","title":"Fledex.Color.Names.carolina_blue/0","doc":"","ref":"Fledex.Color.Names.html#carolina_blue/0"},{"type":"function","title":"Fledex.Color.Names.carrot_orange/0","doc":"","ref":"Fledex.Color.Names.html#carrot_orange/0"},{"type":"function","title":"Fledex.Color.Names.catawba/0","doc":"","ref":"Fledex.Color.Names.html#catawba/0"},{"type":"function","title":"Fledex.Color.Names.cedar_chest/0","doc":"","ref":"Fledex.Color.Names.html#cedar_chest/0"},{"type":"function","title":"Fledex.Color.Names.celadon/0","doc":"","ref":"Fledex.Color.Names.html#celadon/0"},{"type":"function","title":"Fledex.Color.Names.celeste/0","doc":"","ref":"Fledex.Color.Names.html#celeste/0"},{"type":"function","title":"Fledex.Color.Names.cerise/0","doc":"","ref":"Fledex.Color.Names.html#cerise/0"},{"type":"function","title":"Fledex.Color.Names.cerulean/0","doc":"","ref":"Fledex.Color.Names.html#cerulean/0"},{"type":"function","title":"Fledex.Color.Names.cerulean_blue/0","doc":"","ref":"Fledex.Color.Names.html#cerulean_blue/0"},{"type":"function","title":"Fledex.Color.Names.cerulean_crayola_/0","doc":"","ref":"Fledex.Color.Names.html#cerulean_crayola_/0"},{"type":"function","title":"Fledex.Color.Names.cerulean_frost/0","doc":"","ref":"Fledex.Color.Names.html#cerulean_frost/0"},{"type":"function","title":"Fledex.Color.Names.champagne/0","doc":"","ref":"Fledex.Color.Names.html#champagne/0"},{"type":"function","title":"Fledex.Color.Names.champagne_pink/0","doc":"","ref":"Fledex.Color.Names.html#champagne_pink/0"},{"type":"function","title":"Fledex.Color.Names.charcoal/0","doc":"","ref":"Fledex.Color.Names.html#charcoal/0"},{"type":"function","title":"Fledex.Color.Names.charm_pink/0","doc":"","ref":"Fledex.Color.Names.html#charm_pink/0"},{"type":"function","title":"Fledex.Color.Names.chartreuse_web_/0","doc":"","ref":"Fledex.Color.Names.html#chartreuse_web_/0"},{"type":"function","title":"Fledex.Color.Names.cherry_blossom_pink/0","doc":"","ref":"Fledex.Color.Names.html#cherry_blossom_pink/0"},{"type":"function","title":"Fledex.Color.Names.chestnut/0","doc":"","ref":"Fledex.Color.Names.html#chestnut/0"},{"type":"function","title":"Fledex.Color.Names.chili_red/0","doc":"","ref":"Fledex.Color.Names.html#chili_red/0"},{"type":"function","title":"Fledex.Color.Names.china_pink/0","doc":"","ref":"Fledex.Color.Names.html#china_pink/0"},{"type":"function","title":"Fledex.Color.Names.chinese_red/0","doc":"","ref":"Fledex.Color.Names.html#chinese_red/0"},{"type":"function","title":"Fledex.Color.Names.chinese_violet/0","doc":"","ref":"Fledex.Color.Names.html#chinese_violet/0"},{"type":"function","title":"Fledex.Color.Names.chinese_yellow/0","doc":"","ref":"Fledex.Color.Names.html#chinese_yellow/0"},{"type":"function","title":"Fledex.Color.Names.chocolate_traditional_/0","doc":"","ref":"Fledex.Color.Names.html#chocolate_traditional_/0"},{"type":"function","title":"Fledex.Color.Names.chocolate_web_/0","doc":"","ref":"Fledex.Color.Names.html#chocolate_web_/0"},{"type":"function","title":"Fledex.Color.Names.cinereous/0","doc":"","ref":"Fledex.Color.Names.html#cinereous/0"},{"type":"function","title":"Fledex.Color.Names.cinnabar/0","doc":"","ref":"Fledex.Color.Names.html#cinnabar/0"},{"type":"function","title":"Fledex.Color.Names.cinnamon_satin/0","doc":"","ref":"Fledex.Color.Names.html#cinnamon_satin/0"},{"type":"function","title":"Fledex.Color.Names.citrine/0","doc":"","ref":"Fledex.Color.Names.html#citrine/0"},{"type":"function","title":"Fledex.Color.Names.citron/0","doc":"","ref":"Fledex.Color.Names.html#citron/0"},{"type":"function","title":"Fledex.Color.Names.claret/0","doc":"","ref":"Fledex.Color.Names.html#claret/0"},{"type":"function","title":"Fledex.Color.Names.coffee/0","doc":"","ref":"Fledex.Color.Names.html#coffee/0"},{"type":"function","title":"Fledex.Color.Names.colors/0","doc":"","ref":"Fledex.Color.Names.html#colors/0"},{"type":"function","title":"Fledex.Color.Names.columbia_blue/0","doc":"","ref":"Fledex.Color.Names.html#columbia_blue/0"},{"type":"function","title":"Fledex.Color.Names.congo_pink/0","doc":"","ref":"Fledex.Color.Names.html#congo_pink/0"},{"type":"function","title":"Fledex.Color.Names.cool_grey/0","doc":"","ref":"Fledex.Color.Names.html#cool_grey/0"},{"type":"function","title":"Fledex.Color.Names.copper/0","doc":"","ref":"Fledex.Color.Names.html#copper/0"},{"type":"function","title":"Fledex.Color.Names.copper_crayola_/0","doc":"","ref":"Fledex.Color.Names.html#copper_crayola_/0"},{"type":"function","title":"Fledex.Color.Names.copper_penny/0","doc":"","ref":"Fledex.Color.Names.html#copper_penny/0"},{"type":"function","title":"Fledex.Color.Names.copper_red/0","doc":"","ref":"Fledex.Color.Names.html#copper_red/0"},{"type":"function","title":"Fledex.Color.Names.copper_rose/0","doc":"","ref":"Fledex.Color.Names.html#copper_rose/0"},{"type":"function","title":"Fledex.Color.Names.coquelicot/0","doc":"","ref":"Fledex.Color.Names.html#coquelicot/0"},{"type":"function","title":"Fledex.Color.Names.coral/0","doc":"","ref":"Fledex.Color.Names.html#coral/0"},{"type":"function","title":"Fledex.Color.Names.coral_pink/0","doc":"","ref":"Fledex.Color.Names.html#coral_pink/0"},{"type":"function","title":"Fledex.Color.Names.cordovan/0","doc":"","ref":"Fledex.Color.Names.html#cordovan/0"},{"type":"function","title":"Fledex.Color.Names.corn/0","doc":"","ref":"Fledex.Color.Names.html#corn/0"},{"type":"function","title":"Fledex.Color.Names.cornflower_blue/0","doc":"","ref":"Fledex.Color.Names.html#cornflower_blue/0"},{"type":"function","title":"Fledex.Color.Names.cornsilk/0","doc":"","ref":"Fledex.Color.Names.html#cornsilk/0"},{"type":"function","title":"Fledex.Color.Names.cosmic_cobalt/0","doc":"","ref":"Fledex.Color.Names.html#cosmic_cobalt/0"},{"type":"function","title":"Fledex.Color.Names.cosmic_latte/0","doc":"","ref":"Fledex.Color.Names.html#cosmic_latte/0"},{"type":"function","title":"Fledex.Color.Names.cotton_candy/0","doc":"","ref":"Fledex.Color.Names.html#cotton_candy/0"},{"type":"function","title":"Fledex.Color.Names.coyote_brown/0","doc":"","ref":"Fledex.Color.Names.html#coyote_brown/0"},{"type":"function","title":"Fledex.Color.Names.cream/0","doc":"","ref":"Fledex.Color.Names.html#cream/0"},{"type":"function","title":"Fledex.Color.Names.crimson/0","doc":"","ref":"Fledex.Color.Names.html#crimson/0"},{"type":"function","title":"Fledex.Color.Names.crimson_ua_/0","doc":"","ref":"Fledex.Color.Names.html#crimson_ua_/0"},{"type":"function","title":"Fledex.Color.Names.cultured_pearl/0","doc":"","ref":"Fledex.Color.Names.html#cultured_pearl/0"},{"type":"function","title":"Fledex.Color.Names.cyan/0","doc":"","ref":"Fledex.Color.Names.html#cyan/0"},{"type":"function","title":"Fledex.Color.Names.cyan_process_/0","doc":"","ref":"Fledex.Color.Names.html#cyan_process_/0"},{"type":"function","title":"Fledex.Color.Names.cyber_grape/0","doc":"","ref":"Fledex.Color.Names.html#cyber_grape/0"},{"type":"function","title":"Fledex.Color.Names.cyber_yellow/0","doc":"","ref":"Fledex.Color.Names.html#cyber_yellow/0"},{"type":"function","title":"Fledex.Color.Names.cyclamen/0","doc":"","ref":"Fledex.Color.Names.html#cyclamen/0"},{"type":"function","title":"Fledex.Color.Names.dark_brown/0","doc":"","ref":"Fledex.Color.Names.html#dark_brown/0"},{"type":"function","title":"Fledex.Color.Names.dark_byzantium/0","doc":"","ref":"Fledex.Color.Names.html#dark_byzantium/0"},{"type":"function","title":"Fledex.Color.Names.dark_cyan/0","doc":"","ref":"Fledex.Color.Names.html#dark_cyan/0"},{"type":"function","title":"Fledex.Color.Names.dark_electric_blue/0","doc":"","ref":"Fledex.Color.Names.html#dark_electric_blue/0"},{"type":"function","title":"Fledex.Color.Names.dark_goldenrod/0","doc":"","ref":"Fledex.Color.Names.html#dark_goldenrod/0"},{"type":"function","title":"Fledex.Color.Names.dark_green_x11_/0","doc":"","ref":"Fledex.Color.Names.html#dark_green_x11_/0"},{"type":"function","title":"Fledex.Color.Names.dark_jungle_green/0","doc":"","ref":"Fledex.Color.Names.html#dark_jungle_green/0"},{"type":"function","title":"Fledex.Color.Names.dark_khaki/0","doc":"","ref":"Fledex.Color.Names.html#dark_khaki/0"},{"type":"function","title":"Fledex.Color.Names.dark_lava/0","doc":"","ref":"Fledex.Color.Names.html#dark_lava/0"},{"type":"function","title":"Fledex.Color.Names.dark_liver_horses_/0","doc":"","ref":"Fledex.Color.Names.html#dark_liver_horses_/0"},{"type":"function","title":"Fledex.Color.Names.dark_magenta/0","doc":"","ref":"Fledex.Color.Names.html#dark_magenta/0"},{"type":"function","title":"Fledex.Color.Names.dark_olive_green/0","doc":"","ref":"Fledex.Color.Names.html#dark_olive_green/0"},{"type":"function","title":"Fledex.Color.Names.dark_orange/0","doc":"","ref":"Fledex.Color.Names.html#dark_orange/0"},{"type":"function","title":"Fledex.Color.Names.dark_orchid/0","doc":"","ref":"Fledex.Color.Names.html#dark_orchid/0"},{"type":"function","title":"Fledex.Color.Names.dark_purple/0","doc":"","ref":"Fledex.Color.Names.html#dark_purple/0"},{"type":"function","title":"Fledex.Color.Names.dark_red/0","doc":"","ref":"Fledex.Color.Names.html#dark_red/0"},{"type":"function","title":"Fledex.Color.Names.dark_salmon/0","doc":"","ref":"Fledex.Color.Names.html#dark_salmon/0"},{"type":"function","title":"Fledex.Color.Names.dark_sea_green/0","doc":"","ref":"Fledex.Color.Names.html#dark_sea_green/0"},{"type":"function","title":"Fledex.Color.Names.dark_sienna/0","doc":"","ref":"Fledex.Color.Names.html#dark_sienna/0"},{"type":"function","title":"Fledex.Color.Names.dark_sky_blue/0","doc":"","ref":"Fledex.Color.Names.html#dark_sky_blue/0"},{"type":"function","title":"Fledex.Color.Names.dark_slate_blue/0","doc":"","ref":"Fledex.Color.Names.html#dark_slate_blue/0"},{"type":"function","title":"Fledex.Color.Names.dark_slate_gray/0","doc":"","ref":"Fledex.Color.Names.html#dark_slate_gray/0"},{"type":"function","title":"Fledex.Color.Names.dark_spring_green/0","doc":"","ref":"Fledex.Color.Names.html#dark_spring_green/0"},{"type":"function","title":"Fledex.Color.Names.dark_turquoise/0","doc":"","ref":"Fledex.Color.Names.html#dark_turquoise/0"},{"type":"function","title":"Fledex.Color.Names.dark_violet/0","doc":"","ref":"Fledex.Color.Names.html#dark_violet/0"},{"type":"function","title":"Fledex.Color.Names.davy_s_grey/0","doc":"","ref":"Fledex.Color.Names.html#davy_s_grey/0"},{"type":"function","title":"Fledex.Color.Names.deep_cerise/0","doc":"","ref":"Fledex.Color.Names.html#deep_cerise/0"},{"type":"function","title":"Fledex.Color.Names.deep_champagne/0","doc":"","ref":"Fledex.Color.Names.html#deep_champagne/0"},{"type":"function","title":"Fledex.Color.Names.deep_chestnut/0","doc":"","ref":"Fledex.Color.Names.html#deep_chestnut/0"},{"type":"function","title":"Fledex.Color.Names.deep_jungle_green/0","doc":"","ref":"Fledex.Color.Names.html#deep_jungle_green/0"},{"type":"function","title":"Fledex.Color.Names.deep_pink/0","doc":"","ref":"Fledex.Color.Names.html#deep_pink/0"},{"type":"function","title":"Fledex.Color.Names.deep_saffron/0","doc":"","ref":"Fledex.Color.Names.html#deep_saffron/0"},{"type":"function","title":"Fledex.Color.Names.deep_sky_blue/0","doc":"","ref":"Fledex.Color.Names.html#deep_sky_blue/0"},{"type":"function","title":"Fledex.Color.Names.deep_space_sparkle/0","doc":"","ref":"Fledex.Color.Names.html#deep_space_sparkle/0"},{"type":"function","title":"Fledex.Color.Names.deep_taupe/0","doc":"","ref":"Fledex.Color.Names.html#deep_taupe/0"},{"type":"function","title":"Fledex.Color.Names.denim/0","doc":"","ref":"Fledex.Color.Names.html#denim/0"},{"type":"function","title":"Fledex.Color.Names.denim_blue/0","doc":"","ref":"Fledex.Color.Names.html#denim_blue/0"},{"type":"function","title":"Fledex.Color.Names.desert/0","doc":"","ref":"Fledex.Color.Names.html#desert/0"},{"type":"function","title":"Fledex.Color.Names.desert_sand/0","doc":"","ref":"Fledex.Color.Names.html#desert_sand/0"},{"type":"function","title":"Fledex.Color.Names.dim_gray/0","doc":"","ref":"Fledex.Color.Names.html#dim_gray/0"},{"type":"function","title":"Fledex.Color.Names.dodger_blue/0","doc":"","ref":"Fledex.Color.Names.html#dodger_blue/0"},{"type":"function","title":"Fledex.Color.Names.drab_dark_brown/0","doc":"","ref":"Fledex.Color.Names.html#drab_dark_brown/0"},{"type":"function","title":"Fledex.Color.Names.duke_blue/0","doc":"","ref":"Fledex.Color.Names.html#duke_blue/0"},{"type":"function","title":"Fledex.Color.Names.dutch_white/0","doc":"","ref":"Fledex.Color.Names.html#dutch_white/0"},{"type":"function","title":"Fledex.Color.Names.ebony/0","doc":"","ref":"Fledex.Color.Names.html#ebony/0"},{"type":"function","title":"Fledex.Color.Names.ecru/0","doc":"","ref":"Fledex.Color.Names.html#ecru/0"},{"type":"function","title":"Fledex.Color.Names.eerie_black/0","doc":"","ref":"Fledex.Color.Names.html#eerie_black/0"},{"type":"function","title":"Fledex.Color.Names.eggplant/0","doc":"","ref":"Fledex.Color.Names.html#eggplant/0"},{"type":"function","title":"Fledex.Color.Names.eggshell/0","doc":"","ref":"Fledex.Color.Names.html#eggshell/0"},{"type":"function","title":"Fledex.Color.Names.electric_lime/0","doc":"","ref":"Fledex.Color.Names.html#electric_lime/0"},{"type":"function","title":"Fledex.Color.Names.electric_purple/0","doc":"","ref":"Fledex.Color.Names.html#electric_purple/0"},{"type":"function","title":"Fledex.Color.Names.electric_violet/0","doc":"","ref":"Fledex.Color.Names.html#electric_violet/0"},{"type":"function","title":"Fledex.Color.Names.emerald/0","doc":"","ref":"Fledex.Color.Names.html#emerald/0"},{"type":"function","title":"Fledex.Color.Names.eminence/0","doc":"","ref":"Fledex.Color.Names.html#eminence/0"},{"type":"function","title":"Fledex.Color.Names.english_lavender/0","doc":"","ref":"Fledex.Color.Names.html#english_lavender/0"},{"type":"function","title":"Fledex.Color.Names.english_red/0","doc":"","ref":"Fledex.Color.Names.html#english_red/0"},{"type":"function","title":"Fledex.Color.Names.english_vermillion/0","doc":"","ref":"Fledex.Color.Names.html#english_vermillion/0"},{"type":"function","title":"Fledex.Color.Names.english_violet/0","doc":"","ref":"Fledex.Color.Names.html#english_violet/0"},{"type":"function","title":"Fledex.Color.Names.erin/0","doc":"","ref":"Fledex.Color.Names.html#erin/0"},{"type":"function","title":"Fledex.Color.Names.eton_blue/0","doc":"","ref":"Fledex.Color.Names.html#eton_blue/0"},{"type":"function","title":"Fledex.Color.Names.fallow/0","doc":"","ref":"Fledex.Color.Names.html#fallow/0"},{"type":"function","title":"Fledex.Color.Names.falu_red/0","doc":"","ref":"Fledex.Color.Names.html#falu_red/0"},{"type":"function","title":"Fledex.Color.Names.fandango/0","doc":"","ref":"Fledex.Color.Names.html#fandango/0"},{"type":"function","title":"Fledex.Color.Names.fandango_pink/0","doc":"","ref":"Fledex.Color.Names.html#fandango_pink/0"},{"type":"function","title":"Fledex.Color.Names.fawn/0","doc":"","ref":"Fledex.Color.Names.html#fawn/0"},{"type":"function","title":"Fledex.Color.Names.fern_green/0","doc":"","ref":"Fledex.Color.Names.html#fern_green/0"},{"type":"function","title":"Fledex.Color.Names.field_drab/0","doc":"","ref":"Fledex.Color.Names.html#field_drab/0"},{"type":"function","title":"Fledex.Color.Names.fiery_rose/0","doc":"","ref":"Fledex.Color.Names.html#fiery_rose/0"},{"type":"function","title":"Fledex.Color.Names.finn/0","doc":"","ref":"Fledex.Color.Names.html#finn/0"},{"type":"function","title":"Fledex.Color.Names.fire_engine_red/0","doc":"","ref":"Fledex.Color.Names.html#fire_engine_red/0"},{"type":"function","title":"Fledex.Color.Names.firebrick/0","doc":"","ref":"Fledex.Color.Names.html#firebrick/0"},{"type":"function","title":"Fledex.Color.Names.flame/0","doc":"","ref":"Fledex.Color.Names.html#flame/0"},{"type":"function","title":"Fledex.Color.Names.flax/0","doc":"","ref":"Fledex.Color.Names.html#flax/0"},{"type":"function","title":"Fledex.Color.Names.flirt/0","doc":"","ref":"Fledex.Color.Names.html#flirt/0"},{"type":"function","title":"Fledex.Color.Names.floral_white/0","doc":"","ref":"Fledex.Color.Names.html#floral_white/0"},{"type":"function","title":"Fledex.Color.Names.forest_green_web_/0","doc":"","ref":"Fledex.Color.Names.html#forest_green_web_/0"},{"type":"function","title":"Fledex.Color.Names.french_beige/0","doc":"","ref":"Fledex.Color.Names.html#french_beige/0"},{"type":"function","title":"Fledex.Color.Names.french_bistre/0","doc":"","ref":"Fledex.Color.Names.html#french_bistre/0"},{"type":"function","title":"Fledex.Color.Names.french_blue/0","doc":"","ref":"Fledex.Color.Names.html#french_blue/0"},{"type":"function","title":"Fledex.Color.Names.french_fuchsia/0","doc":"","ref":"Fledex.Color.Names.html#french_fuchsia/0"},{"type":"function","title":"Fledex.Color.Names.french_lilac/0","doc":"","ref":"Fledex.Color.Names.html#french_lilac/0"},{"type":"function","title":"Fledex.Color.Names.french_lime/0","doc":"","ref":"Fledex.Color.Names.html#french_lime/0"},{"type":"function","title":"Fledex.Color.Names.french_mauve/0","doc":"","ref":"Fledex.Color.Names.html#french_mauve/0"},{"type":"function","title":"Fledex.Color.Names.french_pink/0","doc":"","ref":"Fledex.Color.Names.html#french_pink/0"},{"type":"function","title":"Fledex.Color.Names.french_raspberry/0","doc":"","ref":"Fledex.Color.Names.html#french_raspberry/0"},{"type":"function","title":"Fledex.Color.Names.french_sky_blue/0","doc":"","ref":"Fledex.Color.Names.html#french_sky_blue/0"},{"type":"function","title":"Fledex.Color.Names.french_violet/0","doc":"","ref":"Fledex.Color.Names.html#french_violet/0"},{"type":"function","title":"Fledex.Color.Names.frostbite/0","doc":"","ref":"Fledex.Color.Names.html#frostbite/0"},{"type":"function","title":"Fledex.Color.Names.fuchsia/0","doc":"","ref":"Fledex.Color.Names.html#fuchsia/0"},{"type":"function","title":"Fledex.Color.Names.fuchsia_crayola_/0","doc":"","ref":"Fledex.Color.Names.html#fuchsia_crayola_/0"},{"type":"function","title":"Fledex.Color.Names.fulvous/0","doc":"","ref":"Fledex.Color.Names.html#fulvous/0"},{"type":"function","title":"Fledex.Color.Names.fuzzy_wuzzy/0","doc":"","ref":"Fledex.Color.Names.html#fuzzy_wuzzy/0"},{"type":"function","title":"Fledex.Color.Names.gainsboro/0","doc":"","ref":"Fledex.Color.Names.html#gainsboro/0"},{"type":"function","title":"Fledex.Color.Names.gamboge/0","doc":"","ref":"Fledex.Color.Names.html#gamboge/0"},{"type":"function","title":"Fledex.Color.Names.generic_viridian/0","doc":"","ref":"Fledex.Color.Names.html#generic_viridian/0"},{"type":"function","title":"Fledex.Color.Names.get_color_int/1","doc":"","ref":"Fledex.Color.Names.html#get_color_int/1"},{"type":"function","title":"Fledex.Color.Names.get_color_sub_pixels/1","doc":"","ref":"Fledex.Color.Names.html#get_color_sub_pixels/1"},{"type":"function","title":"Fledex.Color.Names.ghost_white/0","doc":"","ref":"Fledex.Color.Names.html#ghost_white/0"},{"type":"function","title":"Fledex.Color.Names.glaucous/0","doc":"","ref":"Fledex.Color.Names.html#glaucous/0"},{"type":"function","title":"Fledex.Color.Names.glossy_grape/0","doc":"","ref":"Fledex.Color.Names.html#glossy_grape/0"},{"type":"function","title":"Fledex.Color.Names.go_green/0","doc":"","ref":"Fledex.Color.Names.html#go_green/0"},{"type":"function","title":"Fledex.Color.Names.gold_crayola_/0","doc":"","ref":"Fledex.Color.Names.html#gold_crayola_/0"},{"type":"function","title":"Fledex.Color.Names.gold_fusion/0","doc":"","ref":"Fledex.Color.Names.html#gold_fusion/0"},{"type":"function","title":"Fledex.Color.Names.gold_metallic_/0","doc":"","ref":"Fledex.Color.Names.html#gold_metallic_/0"},{"type":"function","title":"Fledex.Color.Names.gold_web_golden_/0","doc":"","ref":"Fledex.Color.Names.html#gold_web_golden_/0"},{"type":"function","title":"Fledex.Color.Names.golden_brown/0","doc":"","ref":"Fledex.Color.Names.html#golden_brown/0"},{"type":"function","title":"Fledex.Color.Names.golden_poppy/0","doc":"","ref":"Fledex.Color.Names.html#golden_poppy/0"},{"type":"function","title":"Fledex.Color.Names.golden_yellow/0","doc":"","ref":"Fledex.Color.Names.html#golden_yellow/0"},{"type":"function","title":"Fledex.Color.Names.goldenrod/0","doc":"","ref":"Fledex.Color.Names.html#goldenrod/0"},{"type":"function","title":"Fledex.Color.Names.gotham_green/0","doc":"","ref":"Fledex.Color.Names.html#gotham_green/0"},{"type":"function","title":"Fledex.Color.Names.granite_gray/0","doc":"","ref":"Fledex.Color.Names.html#granite_gray/0"},{"type":"function","title":"Fledex.Color.Names.granny_smith_apple/0","doc":"","ref":"Fledex.Color.Names.html#granny_smith_apple/0"},{"type":"function","title":"Fledex.Color.Names.gray_web_/0","doc":"","ref":"Fledex.Color.Names.html#gray_web_/0"},{"type":"function","title":"Fledex.Color.Names.gray_x11_gray_/0","doc":"","ref":"Fledex.Color.Names.html#gray_x11_gray_/0"},{"type":"function","title":"Fledex.Color.Names.green/0","doc":"","ref":"Fledex.Color.Names.html#green/0"},{"type":"function","title":"Fledex.Color.Names.green_blue/0","doc":"","ref":"Fledex.Color.Names.html#green_blue/0"},{"type":"function","title":"Fledex.Color.Names.green_crayola_/0","doc":"","ref":"Fledex.Color.Names.html#green_crayola_/0"},{"type":"function","title":"Fledex.Color.Names.green_lizard/0","doc":"","ref":"Fledex.Color.Names.html#green_lizard/0"},{"type":"function","title":"Fledex.Color.Names.green_munsell_/0","doc":"","ref":"Fledex.Color.Names.html#green_munsell_/0"},{"type":"function","title":"Fledex.Color.Names.green_ncs_/0","doc":"","ref":"Fledex.Color.Names.html#green_ncs_/0"},{"type":"function","title":"Fledex.Color.Names.green_pantone_/0","doc":"","ref":"Fledex.Color.Names.html#green_pantone_/0"},{"type":"function","title":"Fledex.Color.Names.green_pigment_/0","doc":"","ref":"Fledex.Color.Names.html#green_pigment_/0"},{"type":"function","title":"Fledex.Color.Names.green_sheen/0","doc":"","ref":"Fledex.Color.Names.html#green_sheen/0"},{"type":"function","title":"Fledex.Color.Names.green_web_/0","doc":"","ref":"Fledex.Color.Names.html#green_web_/0"},{"type":"function","title":"Fledex.Color.Names.gunmetal/0","doc":"","ref":"Fledex.Color.Names.html#gunmetal/0"},{"type":"function","title":"Fledex.Color.Names.hansa_yellow/0","doc":"","ref":"Fledex.Color.Names.html#hansa_yellow/0"},{"type":"function","title":"Fledex.Color.Names.harlequin/0","doc":"","ref":"Fledex.Color.Names.html#harlequin/0"},{"type":"function","title":"Fledex.Color.Names.harvest_gold/0","doc":"","ref":"Fledex.Color.Names.html#harvest_gold/0"},{"type":"function","title":"Fledex.Color.Names.heat_wave/0","doc":"","ref":"Fledex.Color.Names.html#heat_wave/0"},{"type":"function","title":"Fledex.Color.Names.heliotrope/0","doc":"","ref":"Fledex.Color.Names.html#heliotrope/0"},{"type":"function","title":"Fledex.Color.Names.heliotrope_gray/0","doc":"","ref":"Fledex.Color.Names.html#heliotrope_gray/0"},{"type":"function","title":"Fledex.Color.Names.hollywood_cerise/0","doc":"","ref":"Fledex.Color.Names.html#hollywood_cerise/0"},{"type":"function","title":"Fledex.Color.Names.honolulu_blue/0","doc":"","ref":"Fledex.Color.Names.html#honolulu_blue/0"},{"type":"function","title":"Fledex.Color.Names.hooker_s_green/0","doc":"","ref":"Fledex.Color.Names.html#hooker_s_green/0"},{"type":"function","title":"Fledex.Color.Names.hot_magenta/0","doc":"","ref":"Fledex.Color.Names.html#hot_magenta/0"},{"type":"function","title":"Fledex.Color.Names.hot_pink/0","doc":"","ref":"Fledex.Color.Names.html#hot_pink/0"},{"type":"function","title":"Fledex.Color.Names.hunter_green/0","doc":"","ref":"Fledex.Color.Names.html#hunter_green/0"},{"type":"function","title":"Fledex.Color.Names.iceberg/0","doc":"","ref":"Fledex.Color.Names.html#iceberg/0"},{"type":"function","title":"Fledex.Color.Names.illuminating_emerald/0","doc":"","ref":"Fledex.Color.Names.html#illuminating_emerald/0"},{"type":"function","title":"Fledex.Color.Names.imperial_red/0","doc":"","ref":"Fledex.Color.Names.html#imperial_red/0"},{"type":"function","title":"Fledex.Color.Names.inchworm/0","doc":"","ref":"Fledex.Color.Names.html#inchworm/0"},{"type":"function","title":"Fledex.Color.Names.independence/0","doc":"","ref":"Fledex.Color.Names.html#independence/0"},{"type":"function","title":"Fledex.Color.Names.india_green/0","doc":"","ref":"Fledex.Color.Names.html#india_green/0"},{"type":"function","title":"Fledex.Color.Names.indian_red/0","doc":"","ref":"Fledex.Color.Names.html#indian_red/0"},{"type":"function","title":"Fledex.Color.Names.indian_yellow/0","doc":"","ref":"Fledex.Color.Names.html#indian_yellow/0"},{"type":"function","title":"Fledex.Color.Names.indigo/0","doc":"","ref":"Fledex.Color.Names.html#indigo/0"},{"type":"function","title":"Fledex.Color.Names.indigo_dye/0","doc":"","ref":"Fledex.Color.Names.html#indigo_dye/0"},{"type":"function","title":"Fledex.Color.Names.international_klein_blue/0","doc":"","ref":"Fledex.Color.Names.html#international_klein_blue/0"},{"type":"function","title":"Fledex.Color.Names.international_orange_engineering_/0","doc":"","ref":"Fledex.Color.Names.html#international_orange_engineering_/0"},{"type":"function","title":"Fledex.Color.Names.international_orange_golden_gate_bridge_/0","doc":"","ref":"Fledex.Color.Names.html#international_orange_golden_gate_bridge_/0"},{"type":"function","title":"Fledex.Color.Names.irresistible/0","doc":"","ref":"Fledex.Color.Names.html#irresistible/0"},{"type":"function","title":"Fledex.Color.Names.isabelline/0","doc":"","ref":"Fledex.Color.Names.html#isabelline/0"},{"type":"function","title":"Fledex.Color.Names.italian_sky_blue/0","doc":"","ref":"Fledex.Color.Names.html#italian_sky_blue/0"},{"type":"function","title":"Fledex.Color.Names.ivory/0","doc":"","ref":"Fledex.Color.Names.html#ivory/0"},{"type":"function","title":"Fledex.Color.Names.japanese_carmine/0","doc":"","ref":"Fledex.Color.Names.html#japanese_carmine/0"},{"type":"function","title":"Fledex.Color.Names.japanese_violet/0","doc":"","ref":"Fledex.Color.Names.html#japanese_violet/0"},{"type":"function","title":"Fledex.Color.Names.jasmine/0","doc":"","ref":"Fledex.Color.Names.html#jasmine/0"},{"type":"function","title":"Fledex.Color.Names.jazzberry_jam/0","doc":"","ref":"Fledex.Color.Names.html#jazzberry_jam/0"},{"type":"function","title":"Fledex.Color.Names.jet/0","doc":"","ref":"Fledex.Color.Names.html#jet/0"},{"type":"function","title":"Fledex.Color.Names.jonquil/0","doc":"","ref":"Fledex.Color.Names.html#jonquil/0"},{"type":"function","title":"Fledex.Color.Names.june_bud/0","doc":"","ref":"Fledex.Color.Names.html#june_bud/0"},{"type":"function","title":"Fledex.Color.Names.jungle_green/0","doc":"","ref":"Fledex.Color.Names.html#jungle_green/0"},{"type":"function","title":"Fledex.Color.Names.kelly_green/0","doc":"","ref":"Fledex.Color.Names.html#kelly_green/0"},{"type":"function","title":"Fledex.Color.Names.keppel/0","doc":"","ref":"Fledex.Color.Names.html#keppel/0"},{"type":"function","title":"Fledex.Color.Names.key_lime/0","doc":"","ref":"Fledex.Color.Names.html#key_lime/0"},{"type":"function","title":"Fledex.Color.Names.khaki_web_/0","doc":"","ref":"Fledex.Color.Names.html#khaki_web_/0"},{"type":"function","title":"Fledex.Color.Names.khaki_x11_light_khaki_/0","doc":"","ref":"Fledex.Color.Names.html#khaki_x11_light_khaki_/0"},{"type":"function","title":"Fledex.Color.Names.kobe/0","doc":"","ref":"Fledex.Color.Names.html#kobe/0"},{"type":"function","title":"Fledex.Color.Names.kobi/0","doc":"","ref":"Fledex.Color.Names.html#kobi/0"},{"type":"function","title":"Fledex.Color.Names.kobicha/0","doc":"","ref":"Fledex.Color.Names.html#kobicha/0"},{"type":"function","title":"Fledex.Color.Names.ksu_purple/0","doc":"","ref":"Fledex.Color.Names.html#ksu_purple/0"},{"type":"function","title":"Fledex.Color.Names.languid_lavender/0","doc":"","ref":"Fledex.Color.Names.html#languid_lavender/0"},{"type":"function","title":"Fledex.Color.Names.lapis_lazuli/0","doc":"","ref":"Fledex.Color.Names.html#lapis_lazuli/0"},{"type":"function","title":"Fledex.Color.Names.laser_lemon/0","doc":"","ref":"Fledex.Color.Names.html#laser_lemon/0"},{"type":"function","title":"Fledex.Color.Names.laurel_green/0","doc":"","ref":"Fledex.Color.Names.html#laurel_green/0"},{"type":"function","title":"Fledex.Color.Names.lava/0","doc":"","ref":"Fledex.Color.Names.html#lava/0"},{"type":"function","title":"Fledex.Color.Names.lavender_blue/0","doc":"","ref":"Fledex.Color.Names.html#lavender_blue/0"},{"type":"function","title":"Fledex.Color.Names.lavender_blush/0","doc":"","ref":"Fledex.Color.Names.html#lavender_blush/0"},{"type":"function","title":"Fledex.Color.Names.lavender_floral_/0","doc":"","ref":"Fledex.Color.Names.html#lavender_floral_/0"},{"type":"function","title":"Fledex.Color.Names.lavender_gray/0","doc":"","ref":"Fledex.Color.Names.html#lavender_gray/0"},{"type":"function","title":"Fledex.Color.Names.lavender_web_/0","doc":"","ref":"Fledex.Color.Names.html#lavender_web_/0"},{"type":"function","title":"Fledex.Color.Names.lawn_green/0","doc":"","ref":"Fledex.Color.Names.html#lawn_green/0"},{"type":"function","title":"Fledex.Color.Names.lemon/0","doc":"","ref":"Fledex.Color.Names.html#lemon/0"},{"type":"function","title":"Fledex.Color.Names.lemon_chiffon/0","doc":"","ref":"Fledex.Color.Names.html#lemon_chiffon/0"},{"type":"function","title":"Fledex.Color.Names.lemon_curry/0","doc":"","ref":"Fledex.Color.Names.html#lemon_curry/0"},{"type":"function","title":"Fledex.Color.Names.lemon_glacier/0","doc":"","ref":"Fledex.Color.Names.html#lemon_glacier/0"},{"type":"function","title":"Fledex.Color.Names.lemon_meringue/0","doc":"","ref":"Fledex.Color.Names.html#lemon_meringue/0"},{"type":"function","title":"Fledex.Color.Names.lemon_yellow/0","doc":"","ref":"Fledex.Color.Names.html#lemon_yellow/0"},{"type":"function","title":"Fledex.Color.Names.lemon_yellow_crayola_/0","doc":"","ref":"Fledex.Color.Names.html#lemon_yellow_crayola_/0"},{"type":"function","title":"Fledex.Color.Names.liberty/0","doc":"","ref":"Fledex.Color.Names.html#liberty/0"},{"type":"function","title":"Fledex.Color.Names.light_blue/0","doc":"","ref":"Fledex.Color.Names.html#light_blue/0"},{"type":"function","title":"Fledex.Color.Names.light_coral/0","doc":"","ref":"Fledex.Color.Names.html#light_coral/0"},{"type":"function","title":"Fledex.Color.Names.light_cornflower_blue/0","doc":"","ref":"Fledex.Color.Names.html#light_cornflower_blue/0"},{"type":"function","title":"Fledex.Color.Names.light_cyan/0","doc":"","ref":"Fledex.Color.Names.html#light_cyan/0"},{"type":"function","title":"Fledex.Color.Names.light_french_beige/0","doc":"","ref":"Fledex.Color.Names.html#light_french_beige/0"},{"type":"function","title":"Fledex.Color.Names.light_goldenrod_yellow/0","doc":"","ref":"Fledex.Color.Names.html#light_goldenrod_yellow/0"},{"type":"function","title":"Fledex.Color.Names.light_gray/0","doc":"","ref":"Fledex.Color.Names.html#light_gray/0"},{"type":"function","title":"Fledex.Color.Names.light_green/0","doc":"","ref":"Fledex.Color.Names.html#light_green/0"},{"type":"function","title":"Fledex.Color.Names.light_orange/0","doc":"","ref":"Fledex.Color.Names.html#light_orange/0"},{"type":"function","title":"Fledex.Color.Names.light_periwinkle/0","doc":"","ref":"Fledex.Color.Names.html#light_periwinkle/0"},{"type":"function","title":"Fledex.Color.Names.light_pink/0","doc":"","ref":"Fledex.Color.Names.html#light_pink/0"},{"type":"function","title":"Fledex.Color.Names.light_salmon/0","doc":"","ref":"Fledex.Color.Names.html#light_salmon/0"},{"type":"function","title":"Fledex.Color.Names.light_sea_green/0","doc":"","ref":"Fledex.Color.Names.html#light_sea_green/0"},{"type":"function","title":"Fledex.Color.Names.light_sky_blue/0","doc":"","ref":"Fledex.Color.Names.html#light_sky_blue/0"},{"type":"function","title":"Fledex.Color.Names.light_slate_gray/0","doc":"","ref":"Fledex.Color.Names.html#light_slate_gray/0"},{"type":"function","title":"Fledex.Color.Names.light_steel_blue/0","doc":"","ref":"Fledex.Color.Names.html#light_steel_blue/0"},{"type":"function","title":"Fledex.Color.Names.light_yellow/0","doc":"","ref":"Fledex.Color.Names.html#light_yellow/0"},{"type":"function","title":"Fledex.Color.Names.lilac/0","doc":"","ref":"Fledex.Color.Names.html#lilac/0"},{"type":"function","title":"Fledex.Color.Names.lilac_luster/0","doc":"","ref":"Fledex.Color.Names.html#lilac_luster/0"},{"type":"function","title":"Fledex.Color.Names.lime_color_wheel_/0","doc":"","ref":"Fledex.Color.Names.html#lime_color_wheel_/0"},{"type":"function","title":"Fledex.Color.Names.lime_green/0","doc":"","ref":"Fledex.Color.Names.html#lime_green/0"},{"type":"function","title":"Fledex.Color.Names.lime_web_x11_green_/0","doc":"","ref":"Fledex.Color.Names.html#lime_web_x11_green_/0"},{"type":"function","title":"Fledex.Color.Names.lincoln_green/0","doc":"","ref":"Fledex.Color.Names.html#lincoln_green/0"},{"type":"function","title":"Fledex.Color.Names.linen/0","doc":"","ref":"Fledex.Color.Names.html#linen/0"},{"type":"function","title":"Fledex.Color.Names.lion/0","doc":"","ref":"Fledex.Color.Names.html#lion/0"},{"type":"function","title":"Fledex.Color.Names.liseran_purple/0","doc":"","ref":"Fledex.Color.Names.html#liseran_purple/0"},{"type":"function","title":"Fledex.Color.Names.little_boy_blue/0","doc":"","ref":"Fledex.Color.Names.html#little_boy_blue/0"},{"type":"function","title":"Fledex.Color.Names.liver/0","doc":"","ref":"Fledex.Color.Names.html#liver/0"},{"type":"function","title":"Fledex.Color.Names.liver_chestnut/0","doc":"","ref":"Fledex.Color.Names.html#liver_chestnut/0"},{"type":"function","title":"Fledex.Color.Names.liver_dogs_/0","doc":"","ref":"Fledex.Color.Names.html#liver_dogs_/0"},{"type":"function","title":"Fledex.Color.Names.liver_organ_/0","doc":"","ref":"Fledex.Color.Names.html#liver_organ_/0"},{"type":"function","title":"Fledex.Color.Names.livid/0","doc":"","ref":"Fledex.Color.Names.html#livid/0"},{"type":"function","title":"Fledex.Color.Names.macaroni_and_cheese/0","doc":"","ref":"Fledex.Color.Names.html#macaroni_and_cheese/0"},{"type":"function","title":"Fledex.Color.Names.madder_lake/0","doc":"","ref":"Fledex.Color.Names.html#madder_lake/0"},{"type":"function","title":"Fledex.Color.Names.magenta/0","doc":"","ref":"Fledex.Color.Names.html#magenta/0"},{"type":"function","title":"Fledex.Color.Names.magenta_crayola_/0","doc":"","ref":"Fledex.Color.Names.html#magenta_crayola_/0"},{"type":"function","title":"Fledex.Color.Names.magenta_dye_/0","doc":"","ref":"Fledex.Color.Names.html#magenta_dye_/0"},{"type":"function","title":"Fledex.Color.Names.magenta_haze/0","doc":"","ref":"Fledex.Color.Names.html#magenta_haze/0"},{"type":"function","title":"Fledex.Color.Names.magenta_pantone_/0","doc":"","ref":"Fledex.Color.Names.html#magenta_pantone_/0"},{"type":"function","title":"Fledex.Color.Names.magenta_process_/0","doc":"","ref":"Fledex.Color.Names.html#magenta_process_/0"},{"type":"function","title":"Fledex.Color.Names.magic_mint/0","doc":"","ref":"Fledex.Color.Names.html#magic_mint/0"},{"type":"function","title":"Fledex.Color.Names.magnolia/0","doc":"","ref":"Fledex.Color.Names.html#magnolia/0"},{"type":"function","title":"Fledex.Color.Names.mahogany/0","doc":"","ref":"Fledex.Color.Names.html#mahogany/0"},{"type":"function","title":"Fledex.Color.Names.maize/0","doc":"","ref":"Fledex.Color.Names.html#maize/0"},{"type":"function","title":"Fledex.Color.Names.maize_crayola_/0","doc":"","ref":"Fledex.Color.Names.html#maize_crayola_/0"},{"type":"function","title":"Fledex.Color.Names.majorelle_blue/0","doc":"","ref":"Fledex.Color.Names.html#majorelle_blue/0"},{"type":"function","title":"Fledex.Color.Names.malachite/0","doc":"","ref":"Fledex.Color.Names.html#malachite/0"},{"type":"function","title":"Fledex.Color.Names.manatee/0","doc":"","ref":"Fledex.Color.Names.html#manatee/0"},{"type":"function","title":"Fledex.Color.Names.mandarin/0","doc":"","ref":"Fledex.Color.Names.html#mandarin/0"},{"type":"function","title":"Fledex.Color.Names.mango/0","doc":"","ref":"Fledex.Color.Names.html#mango/0"},{"type":"function","title":"Fledex.Color.Names.mango_tango/0","doc":"","ref":"Fledex.Color.Names.html#mango_tango/0"},{"type":"function","title":"Fledex.Color.Names.mantis/0","doc":"","ref":"Fledex.Color.Names.html#mantis/0"},{"type":"function","title":"Fledex.Color.Names.mardi_gras/0","doc":"","ref":"Fledex.Color.Names.html#mardi_gras/0"},{"type":"function","title":"Fledex.Color.Names.marigold/0","doc":"","ref":"Fledex.Color.Names.html#marigold/0"},{"type":"function","title":"Fledex.Color.Names.maroon_crayola_/0","doc":"","ref":"Fledex.Color.Names.html#maroon_crayola_/0"},{"type":"function","title":"Fledex.Color.Names.maroon_web_/0","doc":"","ref":"Fledex.Color.Names.html#maroon_web_/0"},{"type":"function","title":"Fledex.Color.Names.maroon_x11_/0","doc":"","ref":"Fledex.Color.Names.html#maroon_x11_/0"},{"type":"function","title":"Fledex.Color.Names.mauve/0","doc":"","ref":"Fledex.Color.Names.html#mauve/0"},{"type":"function","title":"Fledex.Color.Names.mauve_taupe/0","doc":"","ref":"Fledex.Color.Names.html#mauve_taupe/0"},{"type":"function","title":"Fledex.Color.Names.mauvelous/0","doc":"","ref":"Fledex.Color.Names.html#mauvelous/0"},{"type":"function","title":"Fledex.Color.Names.maximum_blue/0","doc":"","ref":"Fledex.Color.Names.html#maximum_blue/0"},{"type":"function","title":"Fledex.Color.Names.maximum_blue_green/0","doc":"","ref":"Fledex.Color.Names.html#maximum_blue_green/0"},{"type":"function","title":"Fledex.Color.Names.maximum_blue_purple/0","doc":"","ref":"Fledex.Color.Names.html#maximum_blue_purple/0"},{"type":"function","title":"Fledex.Color.Names.maximum_green/0","doc":"","ref":"Fledex.Color.Names.html#maximum_green/0"},{"type":"function","title":"Fledex.Color.Names.maximum_green_yellow/0","doc":"","ref":"Fledex.Color.Names.html#maximum_green_yellow/0"},{"type":"function","title":"Fledex.Color.Names.maximum_purple/0","doc":"","ref":"Fledex.Color.Names.html#maximum_purple/0"},{"type":"function","title":"Fledex.Color.Names.maximum_red/0","doc":"","ref":"Fledex.Color.Names.html#maximum_red/0"},{"type":"function","title":"Fledex.Color.Names.maximum_red_purple/0","doc":"","ref":"Fledex.Color.Names.html#maximum_red_purple/0"},{"type":"function","title":"Fledex.Color.Names.maximum_yellow/0","doc":"","ref":"Fledex.Color.Names.html#maximum_yellow/0"},{"type":"function","title":"Fledex.Color.Names.maximum_yellow_red/0","doc":"","ref":"Fledex.Color.Names.html#maximum_yellow_red/0"},{"type":"function","title":"Fledex.Color.Names.may_green/0","doc":"","ref":"Fledex.Color.Names.html#may_green/0"},{"type":"function","title":"Fledex.Color.Names.maya_blue/0","doc":"","ref":"Fledex.Color.Names.html#maya_blue/0"},{"type":"function","title":"Fledex.Color.Names.medium_aquamarine/0","doc":"","ref":"Fledex.Color.Names.html#medium_aquamarine/0"},{"type":"function","title":"Fledex.Color.Names.medium_blue/0","doc":"","ref":"Fledex.Color.Names.html#medium_blue/0"},{"type":"function","title":"Fledex.Color.Names.medium_candy_apple_red/0","doc":"","ref":"Fledex.Color.Names.html#medium_candy_apple_red/0"},{"type":"function","title":"Fledex.Color.Names.medium_carmine/0","doc":"","ref":"Fledex.Color.Names.html#medium_carmine/0"},{"type":"function","title":"Fledex.Color.Names.medium_champagne/0","doc":"","ref":"Fledex.Color.Names.html#medium_champagne/0"},{"type":"function","title":"Fledex.Color.Names.medium_orchid/0","doc":"","ref":"Fledex.Color.Names.html#medium_orchid/0"},{"type":"function","title":"Fledex.Color.Names.medium_purple/0","doc":"","ref":"Fledex.Color.Names.html#medium_purple/0"},{"type":"function","title":"Fledex.Color.Names.medium_sea_green/0","doc":"","ref":"Fledex.Color.Names.html#medium_sea_green/0"},{"type":"function","title":"Fledex.Color.Names.medium_slate_blue/0","doc":"","ref":"Fledex.Color.Names.html#medium_slate_blue/0"},{"type":"function","title":"Fledex.Color.Names.medium_spring_green/0","doc":"","ref":"Fledex.Color.Names.html#medium_spring_green/0"},{"type":"function","title":"Fledex.Color.Names.medium_turquoise/0","doc":"","ref":"Fledex.Color.Names.html#medium_turquoise/0"},{"type":"function","title":"Fledex.Color.Names.medium_violet_red/0","doc":"","ref":"Fledex.Color.Names.html#medium_violet_red/0"},{"type":"function","title":"Fledex.Color.Names.mellow_apricot/0","doc":"","ref":"Fledex.Color.Names.html#mellow_apricot/0"},{"type":"function","title":"Fledex.Color.Names.mellow_yellow/0","doc":"","ref":"Fledex.Color.Names.html#mellow_yellow/0"},{"type":"function","title":"Fledex.Color.Names.melon/0","doc":"","ref":"Fledex.Color.Names.html#melon/0"},{"type":"function","title":"Fledex.Color.Names.metallic_gold/0","doc":"","ref":"Fledex.Color.Names.html#metallic_gold/0"},{"type":"function","title":"Fledex.Color.Names.metallic_seaweed/0","doc":"","ref":"Fledex.Color.Names.html#metallic_seaweed/0"},{"type":"function","title":"Fledex.Color.Names.metallic_sunburst/0","doc":"","ref":"Fledex.Color.Names.html#metallic_sunburst/0"},{"type":"function","title":"Fledex.Color.Names.mexican_pink/0","doc":"","ref":"Fledex.Color.Names.html#mexican_pink/0"},{"type":"function","title":"Fledex.Color.Names.middle_blue/0","doc":"","ref":"Fledex.Color.Names.html#middle_blue/0"},{"type":"function","title":"Fledex.Color.Names.middle_blue_green/0","doc":"","ref":"Fledex.Color.Names.html#middle_blue_green/0"},{"type":"function","title":"Fledex.Color.Names.middle_blue_purple/0","doc":"","ref":"Fledex.Color.Names.html#middle_blue_purple/0"},{"type":"function","title":"Fledex.Color.Names.middle_green/0","doc":"","ref":"Fledex.Color.Names.html#middle_green/0"},{"type":"function","title":"Fledex.Color.Names.middle_green_yellow/0","doc":"","ref":"Fledex.Color.Names.html#middle_green_yellow/0"},{"type":"function","title":"Fledex.Color.Names.middle_grey/0","doc":"","ref":"Fledex.Color.Names.html#middle_grey/0"},{"type":"function","title":"Fledex.Color.Names.middle_purple/0","doc":"","ref":"Fledex.Color.Names.html#middle_purple/0"},{"type":"function","title":"Fledex.Color.Names.middle_red/0","doc":"","ref":"Fledex.Color.Names.html#middle_red/0"},{"type":"function","title":"Fledex.Color.Names.middle_red_purple/0","doc":"","ref":"Fledex.Color.Names.html#middle_red_purple/0"},{"type":"function","title":"Fledex.Color.Names.middle_yellow/0","doc":"","ref":"Fledex.Color.Names.html#middle_yellow/0"},{"type":"function","title":"Fledex.Color.Names.middle_yellow_red/0","doc":"","ref":"Fledex.Color.Names.html#middle_yellow_red/0"},{"type":"function","title":"Fledex.Color.Names.midnight/0","doc":"","ref":"Fledex.Color.Names.html#midnight/0"},{"type":"function","title":"Fledex.Color.Names.midnight_blue/0","doc":"","ref":"Fledex.Color.Names.html#midnight_blue/0"},{"type":"function","title":"Fledex.Color.Names.midnight_green_eagle_green_/0","doc":"","ref":"Fledex.Color.Names.html#midnight_green_eagle_green_/0"},{"type":"function","title":"Fledex.Color.Names.mikado_yellow/0","doc":"","ref":"Fledex.Color.Names.html#mikado_yellow/0"},{"type":"function","title":"Fledex.Color.Names.mimi_pink/0","doc":"","ref":"Fledex.Color.Names.html#mimi_pink/0"},{"type":"function","title":"Fledex.Color.Names.mindaro/0","doc":"","ref":"Fledex.Color.Names.html#mindaro/0"},{"type":"function","title":"Fledex.Color.Names.ming/0","doc":"","ref":"Fledex.Color.Names.html#ming/0"},{"type":"function","title":"Fledex.Color.Names.minion_yellow/0","doc":"","ref":"Fledex.Color.Names.html#minion_yellow/0"},{"type":"function","title":"Fledex.Color.Names.mint/0","doc":"","ref":"Fledex.Color.Names.html#mint/0"},{"type":"function","title":"Fledex.Color.Names.mint_cream/0","doc":"","ref":"Fledex.Color.Names.html#mint_cream/0"},{"type":"function","title":"Fledex.Color.Names.mint_green/0","doc":"","ref":"Fledex.Color.Names.html#mint_green/0"},{"type":"function","title":"Fledex.Color.Names.misty_moss/0","doc":"","ref":"Fledex.Color.Names.html#misty_moss/0"},{"type":"function","title":"Fledex.Color.Names.misty_rose/0","doc":"","ref":"Fledex.Color.Names.html#misty_rose/0"},{"type":"function","title":"Fledex.Color.Names.mode_beige/0","doc":"","ref":"Fledex.Color.Names.html#mode_beige/0"},{"type":"function","title":"Fledex.Color.Names.mona_lisa/0","doc":"","ref":"Fledex.Color.Names.html#mona_lisa/0"},{"type":"function","title":"Fledex.Color.Names.morning_blue/0","doc":"","ref":"Fledex.Color.Names.html#morning_blue/0"},{"type":"function","title":"Fledex.Color.Names.moss_green/0","doc":"","ref":"Fledex.Color.Names.html#moss_green/0"},{"type":"function","title":"Fledex.Color.Names.mountain_meadow/0","doc":"","ref":"Fledex.Color.Names.html#mountain_meadow/0"},{"type":"function","title":"Fledex.Color.Names.mountbatten_pink/0","doc":"","ref":"Fledex.Color.Names.html#mountbatten_pink/0"},{"type":"function","title":"Fledex.Color.Names.msu_green/0","doc":"","ref":"Fledex.Color.Names.html#msu_green/0"},{"type":"function","title":"Fledex.Color.Names.mulberry/0","doc":"","ref":"Fledex.Color.Names.html#mulberry/0"},{"type":"function","title":"Fledex.Color.Names.mulberry_crayola_/0","doc":"","ref":"Fledex.Color.Names.html#mulberry_crayola_/0"},{"type":"function","title":"Fledex.Color.Names.mustard/0","doc":"","ref":"Fledex.Color.Names.html#mustard/0"},{"type":"function","title":"Fledex.Color.Names.myrtle_green/0","doc":"","ref":"Fledex.Color.Names.html#myrtle_green/0"},{"type":"function","title":"Fledex.Color.Names.mystic/0","doc":"","ref":"Fledex.Color.Names.html#mystic/0"},{"type":"function","title":"Fledex.Color.Names.mystic_maroon/0","doc":"","ref":"Fledex.Color.Names.html#mystic_maroon/0"},{"type":"function","title":"Fledex.Color.Names.nadeshiko_pink/0","doc":"","ref":"Fledex.Color.Names.html#nadeshiko_pink/0"},{"type":"function","title":"Fledex.Color.Names.names/0","doc":"","ref":"Fledex.Color.Names.html#names/0"},{"type":"function","title":"Fledex.Color.Names.naples_yellow/0","doc":"","ref":"Fledex.Color.Names.html#naples_yellow/0"},{"type":"function","title":"Fledex.Color.Names.navajo_white/0","doc":"","ref":"Fledex.Color.Names.html#navajo_white/0"},{"type":"function","title":"Fledex.Color.Names.navy_blue/0","doc":"","ref":"Fledex.Color.Names.html#navy_blue/0"},{"type":"function","title":"Fledex.Color.Names.navy_blue_crayola_/0","doc":"","ref":"Fledex.Color.Names.html#navy_blue_crayola_/0"},{"type":"function","title":"Fledex.Color.Names.neon_blue/0","doc":"","ref":"Fledex.Color.Names.html#neon_blue/0"},{"type":"function","title":"Fledex.Color.Names.neon_fuchsia/0","doc":"","ref":"Fledex.Color.Names.html#neon_fuchsia/0"},{"type":"function","title":"Fledex.Color.Names.neon_green/0","doc":"","ref":"Fledex.Color.Names.html#neon_green/0"},{"type":"function","title":"Fledex.Color.Names.new_york_pink/0","doc":"","ref":"Fledex.Color.Names.html#new_york_pink/0"},{"type":"function","title":"Fledex.Color.Names.nickel/0","doc":"","ref":"Fledex.Color.Names.html#nickel/0"},{"type":"function","title":"Fledex.Color.Names.non_photo_blue/0","doc":"","ref":"Fledex.Color.Names.html#non_photo_blue/0"},{"type":"function","title":"Fledex.Color.Names.nyanza/0","doc":"","ref":"Fledex.Color.Names.html#nyanza/0"},{"type":"function","title":"Fledex.Color.Names.ochre/0","doc":"","ref":"Fledex.Color.Names.html#ochre/0"},{"type":"function","title":"Fledex.Color.Names.old_burgundy/0","doc":"","ref":"Fledex.Color.Names.html#old_burgundy/0"},{"type":"function","title":"Fledex.Color.Names.old_gold/0","doc":"","ref":"Fledex.Color.Names.html#old_gold/0"},{"type":"function","title":"Fledex.Color.Names.old_lace/0","doc":"","ref":"Fledex.Color.Names.html#old_lace/0"},{"type":"function","title":"Fledex.Color.Names.old_lavender/0","doc":"","ref":"Fledex.Color.Names.html#old_lavender/0"},{"type":"function","title":"Fledex.Color.Names.old_mauve/0","doc":"","ref":"Fledex.Color.Names.html#old_mauve/0"},{"type":"function","title":"Fledex.Color.Names.old_rose/0","doc":"","ref":"Fledex.Color.Names.html#old_rose/0"},{"type":"function","title":"Fledex.Color.Names.old_silver/0","doc":"","ref":"Fledex.Color.Names.html#old_silver/0"},{"type":"function","title":"Fledex.Color.Names.olive/0","doc":"","ref":"Fledex.Color.Names.html#olive/0"},{"type":"function","title":"Fledex.Color.Names.olive_drab_3_/0","doc":"","ref":"Fledex.Color.Names.html#olive_drab_3_/0"},{"type":"function","title":"Fledex.Color.Names.olive_drab_7/0","doc":"","ref":"Fledex.Color.Names.html#olive_drab_7/0"},{"type":"function","title":"Fledex.Color.Names.olive_green/0","doc":"","ref":"Fledex.Color.Names.html#olive_green/0"},{"type":"function","title":"Fledex.Color.Names.olivine/0","doc":"","ref":"Fledex.Color.Names.html#olivine/0"},{"type":"function","title":"Fledex.Color.Names.onyx/0","doc":"","ref":"Fledex.Color.Names.html#onyx/0"},{"type":"function","title":"Fledex.Color.Names.opal/0","doc":"","ref":"Fledex.Color.Names.html#opal/0"},{"type":"function","title":"Fledex.Color.Names.opera_mauve/0","doc":"","ref":"Fledex.Color.Names.html#opera_mauve/0"},{"type":"function","title":"Fledex.Color.Names.orange/0","doc":"","ref":"Fledex.Color.Names.html#orange/0"},{"type":"function","title":"Fledex.Color.Names.orange_crayola_/0","doc":"","ref":"Fledex.Color.Names.html#orange_crayola_/0"},{"type":"function","title":"Fledex.Color.Names.orange_pantone_/0","doc":"","ref":"Fledex.Color.Names.html#orange_pantone_/0"},{"type":"function","title":"Fledex.Color.Names.orange_peel/0","doc":"","ref":"Fledex.Color.Names.html#orange_peel/0"},{"type":"function","title":"Fledex.Color.Names.orange_red/0","doc":"","ref":"Fledex.Color.Names.html#orange_red/0"},{"type":"function","title":"Fledex.Color.Names.orange_red_crayola_/0","doc":"","ref":"Fledex.Color.Names.html#orange_red_crayola_/0"},{"type":"function","title":"Fledex.Color.Names.orange_soda/0","doc":"","ref":"Fledex.Color.Names.html#orange_soda/0"},{"type":"function","title":"Fledex.Color.Names.orange_web_/0","doc":"","ref":"Fledex.Color.Names.html#orange_web_/0"},{"type":"function","title":"Fledex.Color.Names.orange_yellow/0","doc":"","ref":"Fledex.Color.Names.html#orange_yellow/0"},{"type":"function","title":"Fledex.Color.Names.orange_yellow_crayola_/0","doc":"","ref":"Fledex.Color.Names.html#orange_yellow_crayola_/0"},{"type":"function","title":"Fledex.Color.Names.orchid/0","doc":"","ref":"Fledex.Color.Names.html#orchid/0"},{"type":"function","title":"Fledex.Color.Names.orchid_crayola_/0","doc":"","ref":"Fledex.Color.Names.html#orchid_crayola_/0"},{"type":"function","title":"Fledex.Color.Names.orchid_pink/0","doc":"","ref":"Fledex.Color.Names.html#orchid_pink/0"},{"type":"function","title":"Fledex.Color.Names.ou_crimson_red/0","doc":"","ref":"Fledex.Color.Names.html#ou_crimson_red/0"},{"type":"function","title":"Fledex.Color.Names.outer_space_crayola_/0","doc":"","ref":"Fledex.Color.Names.html#outer_space_crayola_/0"},{"type":"function","title":"Fledex.Color.Names.outrageous_orange/0","doc":"","ref":"Fledex.Color.Names.html#outrageous_orange/0"},{"type":"function","title":"Fledex.Color.Names.oxblood/0","doc":"","ref":"Fledex.Color.Names.html#oxblood/0"},{"type":"function","title":"Fledex.Color.Names.oxford_blue/0","doc":"","ref":"Fledex.Color.Names.html#oxford_blue/0"},{"type":"function","title":"Fledex.Color.Names.pacific_blue/0","doc":"","ref":"Fledex.Color.Names.html#pacific_blue/0"},{"type":"function","title":"Fledex.Color.Names.pakistan_green/0","doc":"","ref":"Fledex.Color.Names.html#pakistan_green/0"},{"type":"function","title":"Fledex.Color.Names.palatinate_purple/0","doc":"","ref":"Fledex.Color.Names.html#palatinate_purple/0"},{"type":"function","title":"Fledex.Color.Names.pale_aqua/0","doc":"","ref":"Fledex.Color.Names.html#pale_aqua/0"},{"type":"function","title":"Fledex.Color.Names.pale_cerulean/0","doc":"","ref":"Fledex.Color.Names.html#pale_cerulean/0"},{"type":"function","title":"Fledex.Color.Names.pale_dogwood/0","doc":"","ref":"Fledex.Color.Names.html#pale_dogwood/0"},{"type":"function","title":"Fledex.Color.Names.pale_pink/0","doc":"","ref":"Fledex.Color.Names.html#pale_pink/0"},{"type":"function","title":"Fledex.Color.Names.pale_purple_pantone_/0","doc":"","ref":"Fledex.Color.Names.html#pale_purple_pantone_/0"},{"type":"function","title":"Fledex.Color.Names.pale_spring_bud/0","doc":"","ref":"Fledex.Color.Names.html#pale_spring_bud/0"},{"type":"function","title":"Fledex.Color.Names.pansy_purple/0","doc":"","ref":"Fledex.Color.Names.html#pansy_purple/0"},{"type":"function","title":"Fledex.Color.Names.paolo_veronese_green/0","doc":"","ref":"Fledex.Color.Names.html#paolo_veronese_green/0"},{"type":"function","title":"Fledex.Color.Names.papaya_whip/0","doc":"","ref":"Fledex.Color.Names.html#papaya_whip/0"},{"type":"function","title":"Fledex.Color.Names.paradise_pink/0","doc":"","ref":"Fledex.Color.Names.html#paradise_pink/0"},{"type":"function","title":"Fledex.Color.Names.parchment/0","doc":"","ref":"Fledex.Color.Names.html#parchment/0"},{"type":"function","title":"Fledex.Color.Names.paris_green/0","doc":"","ref":"Fledex.Color.Names.html#paris_green/0"},{"type":"function","title":"Fledex.Color.Names.pastel_pink/0","doc":"","ref":"Fledex.Color.Names.html#pastel_pink/0"},{"type":"function","title":"Fledex.Color.Names.patriarch/0","doc":"","ref":"Fledex.Color.Names.html#patriarch/0"},{"type":"function","title":"Fledex.Color.Names.paua/0","doc":"","ref":"Fledex.Color.Names.html#paua/0"},{"type":"function","title":"Fledex.Color.Names.payne_s_grey/0","doc":"","ref":"Fledex.Color.Names.html#payne_s_grey/0"},{"type":"function","title":"Fledex.Color.Names.peach/0","doc":"","ref":"Fledex.Color.Names.html#peach/0"},{"type":"function","title":"Fledex.Color.Names.peach_crayola_/0","doc":"","ref":"Fledex.Color.Names.html#peach_crayola_/0"},{"type":"function","title":"Fledex.Color.Names.peach_puff/0","doc":"","ref":"Fledex.Color.Names.html#peach_puff/0"},{"type":"function","title":"Fledex.Color.Names.pear/0","doc":"","ref":"Fledex.Color.Names.html#pear/0"},{"type":"function","title":"Fledex.Color.Names.pearly_purple/0","doc":"","ref":"Fledex.Color.Names.html#pearly_purple/0"},{"type":"function","title":"Fledex.Color.Names.periwinkle/0","doc":"","ref":"Fledex.Color.Names.html#periwinkle/0"},{"type":"function","title":"Fledex.Color.Names.periwinkle_crayola_/0","doc":"","ref":"Fledex.Color.Names.html#periwinkle_crayola_/0"},{"type":"function","title":"Fledex.Color.Names.permanent_geranium_lake/0","doc":"","ref":"Fledex.Color.Names.html#permanent_geranium_lake/0"},{"type":"function","title":"Fledex.Color.Names.persian_blue/0","doc":"","ref":"Fledex.Color.Names.html#persian_blue/0"},{"type":"function","title":"Fledex.Color.Names.persian_green/0","doc":"","ref":"Fledex.Color.Names.html#persian_green/0"},{"type":"function","title":"Fledex.Color.Names.persian_indigo/0","doc":"","ref":"Fledex.Color.Names.html#persian_indigo/0"},{"type":"function","title":"Fledex.Color.Names.persian_orange/0","doc":"","ref":"Fledex.Color.Names.html#persian_orange/0"},{"type":"function","title":"Fledex.Color.Names.persian_pink/0","doc":"","ref":"Fledex.Color.Names.html#persian_pink/0"},{"type":"function","title":"Fledex.Color.Names.persian_plum/0","doc":"","ref":"Fledex.Color.Names.html#persian_plum/0"},{"type":"function","title":"Fledex.Color.Names.persian_red/0","doc":"","ref":"Fledex.Color.Names.html#persian_red/0"},{"type":"function","title":"Fledex.Color.Names.persian_rose/0","doc":"","ref":"Fledex.Color.Names.html#persian_rose/0"},{"type":"function","title":"Fledex.Color.Names.persimmon/0","doc":"","ref":"Fledex.Color.Names.html#persimmon/0"},{"type":"function","title":"Fledex.Color.Names.pewter_blue/0","doc":"","ref":"Fledex.Color.Names.html#pewter_blue/0"},{"type":"function","title":"Fledex.Color.Names.phlox/0","doc":"","ref":"Fledex.Color.Names.html#phlox/0"},{"type":"function","title":"Fledex.Color.Names.phthalo_blue/0","doc":"","ref":"Fledex.Color.Names.html#phthalo_blue/0"},{"type":"function","title":"Fledex.Color.Names.phthalo_green/0","doc":"","ref":"Fledex.Color.Names.html#phthalo_green/0"},{"type":"function","title":"Fledex.Color.Names.picotee_blue/0","doc":"","ref":"Fledex.Color.Names.html#picotee_blue/0"},{"type":"function","title":"Fledex.Color.Names.pictorial_carmine/0","doc":"","ref":"Fledex.Color.Names.html#pictorial_carmine/0"},{"type":"function","title":"Fledex.Color.Names.piggy_pink/0","doc":"","ref":"Fledex.Color.Names.html#piggy_pink/0"},{"type":"function","title":"Fledex.Color.Names.pine_green/0","doc":"","ref":"Fledex.Color.Names.html#pine_green/0"},{"type":"function","title":"Fledex.Color.Names.pine_tree/0","doc":"","ref":"Fledex.Color.Names.html#pine_tree/0"},{"type":"function","title":"Fledex.Color.Names.pink/0","doc":"","ref":"Fledex.Color.Names.html#pink/0"},{"type":"function","title":"Fledex.Color.Names.pink_lace/0","doc":"","ref":"Fledex.Color.Names.html#pink_lace/0"},{"type":"function","title":"Fledex.Color.Names.pink_lavender/0","doc":"","ref":"Fledex.Color.Names.html#pink_lavender/0"},{"type":"function","title":"Fledex.Color.Names.pink_pantone_/0","doc":"","ref":"Fledex.Color.Names.html#pink_pantone_/0"},{"type":"function","title":"Fledex.Color.Names.pink_sherbet/0","doc":"","ref":"Fledex.Color.Names.html#pink_sherbet/0"},{"type":"function","title":"Fledex.Color.Names.pistachio/0","doc":"","ref":"Fledex.Color.Names.html#pistachio/0"},{"type":"function","title":"Fledex.Color.Names.platinum/0","doc":"","ref":"Fledex.Color.Names.html#platinum/0"},{"type":"function","title":"Fledex.Color.Names.plum/0","doc":"","ref":"Fledex.Color.Names.html#plum/0"},{"type":"function","title":"Fledex.Color.Names.plum_web_/0","doc":"","ref":"Fledex.Color.Names.html#plum_web_/0"},{"type":"function","title":"Fledex.Color.Names.plump_purple/0","doc":"","ref":"Fledex.Color.Names.html#plump_purple/0"},{"type":"function","title":"Fledex.Color.Names.polished_pine/0","doc":"","ref":"Fledex.Color.Names.html#polished_pine/0"},{"type":"function","title":"Fledex.Color.Names.pomp_and_power/0","doc":"","ref":"Fledex.Color.Names.html#pomp_and_power/0"},{"type":"function","title":"Fledex.Color.Names.popstar/0","doc":"","ref":"Fledex.Color.Names.html#popstar/0"},{"type":"function","title":"Fledex.Color.Names.portland_orange/0","doc":"","ref":"Fledex.Color.Names.html#portland_orange/0"},{"type":"function","title":"Fledex.Color.Names.powder_blue/0","doc":"","ref":"Fledex.Color.Names.html#powder_blue/0"},{"type":"function","title":"Fledex.Color.Names.princeton_orange/0","doc":"","ref":"Fledex.Color.Names.html#princeton_orange/0"},{"type":"function","title":"Fledex.Color.Names.process_yellow/0","doc":"","ref":"Fledex.Color.Names.html#process_yellow/0"},{"type":"function","title":"Fledex.Color.Names.prune/0","doc":"","ref":"Fledex.Color.Names.html#prune/0"},{"type":"function","title":"Fledex.Color.Names.prussian_blue/0","doc":"","ref":"Fledex.Color.Names.html#prussian_blue/0"},{"type":"function","title":"Fledex.Color.Names.psychedelic_purple/0","doc":"","ref":"Fledex.Color.Names.html#psychedelic_purple/0"},{"type":"function","title":"Fledex.Color.Names.puce/0","doc":"","ref":"Fledex.Color.Names.html#puce/0"},{"type":"function","title":"Fledex.Color.Names.pullman_brown_ups_brown_/0","doc":"","ref":"Fledex.Color.Names.html#pullman_brown_ups_brown_/0"},{"type":"function","title":"Fledex.Color.Names.pumpkin/0","doc":"","ref":"Fledex.Color.Names.html#pumpkin/0"},{"type":"function","title":"Fledex.Color.Names.purple/0","doc":"","ref":"Fledex.Color.Names.html#purple/0"},{"type":"function","title":"Fledex.Color.Names.purple_mountain_majesty/0","doc":"","ref":"Fledex.Color.Names.html#purple_mountain_majesty/0"},{"type":"function","title":"Fledex.Color.Names.purple_munsell_/0","doc":"","ref":"Fledex.Color.Names.html#purple_munsell_/0"},{"type":"function","title":"Fledex.Color.Names.purple_navy/0","doc":"","ref":"Fledex.Color.Names.html#purple_navy/0"},{"type":"function","title":"Fledex.Color.Names.purple_pizzazz/0","doc":"","ref":"Fledex.Color.Names.html#purple_pizzazz/0"},{"type":"function","title":"Fledex.Color.Names.purple_plum/0","doc":"","ref":"Fledex.Color.Names.html#purple_plum/0"},{"type":"function","title":"Fledex.Color.Names.purple_web_/0","doc":"","ref":"Fledex.Color.Names.html#purple_web_/0"},{"type":"function","title":"Fledex.Color.Names.purple_x11_/0","doc":"","ref":"Fledex.Color.Names.html#purple_x11_/0"},{"type":"function","title":"Fledex.Color.Names.purpureus/0","doc":"","ref":"Fledex.Color.Names.html#purpureus/0"},{"type":"function","title":"Fledex.Color.Names.queen_blue/0","doc":"","ref":"Fledex.Color.Names.html#queen_blue/0"},{"type":"function","title":"Fledex.Color.Names.queen_pink/0","doc":"","ref":"Fledex.Color.Names.html#queen_pink/0"},{"type":"function","title":"Fledex.Color.Names.quick_silver/0","doc":"","ref":"Fledex.Color.Names.html#quick_silver/0"},{"type":"function","title":"Fledex.Color.Names.quinacridone_magenta/0","doc":"","ref":"Fledex.Color.Names.html#quinacridone_magenta/0"},{"type":"function","title":"Fledex.Color.Names.radical_red/0","doc":"","ref":"Fledex.Color.Names.html#radical_red/0"},{"type":"function","title":"Fledex.Color.Names.raisin_black/0","doc":"","ref":"Fledex.Color.Names.html#raisin_black/0"},{"type":"function","title":"Fledex.Color.Names.rajah/0","doc":"","ref":"Fledex.Color.Names.html#rajah/0"},{"type":"function","title":"Fledex.Color.Names.raspberry/0","doc":"","ref":"Fledex.Color.Names.html#raspberry/0"},{"type":"function","title":"Fledex.Color.Names.raspberry_glace_/0","doc":"","ref":"Fledex.Color.Names.html#raspberry_glace_/0"},{"type":"function","title":"Fledex.Color.Names.raspberry_rose/0","doc":"","ref":"Fledex.Color.Names.html#raspberry_rose/0"},{"type":"function","title":"Fledex.Color.Names.raw_sienna/0","doc":"","ref":"Fledex.Color.Names.html#raw_sienna/0"},{"type":"function","title":"Fledex.Color.Names.raw_umber/0","doc":"","ref":"Fledex.Color.Names.html#raw_umber/0"},{"type":"function","title":"Fledex.Color.Names.razzle_dazzle_rose/0","doc":"","ref":"Fledex.Color.Names.html#razzle_dazzle_rose/0"},{"type":"function","title":"Fledex.Color.Names.razzmatazz/0","doc":"","ref":"Fledex.Color.Names.html#razzmatazz/0"},{"type":"function","title":"Fledex.Color.Names.razzmic_berry/0","doc":"","ref":"Fledex.Color.Names.html#razzmic_berry/0"},{"type":"function","title":"Fledex.Color.Names.rebecca_purple/0","doc":"","ref":"Fledex.Color.Names.html#rebecca_purple/0"},{"type":"function","title":"Fledex.Color.Names.red/0","doc":"","ref":"Fledex.Color.Names.html#red/0"},{"type":"function","title":"Fledex.Color.Names.red_crayola_/0","doc":"","ref":"Fledex.Color.Names.html#red_crayola_/0"},{"type":"function","title":"Fledex.Color.Names.red_munsell_/0","doc":"","ref":"Fledex.Color.Names.html#red_munsell_/0"},{"type":"function","title":"Fledex.Color.Names.red_ncs_/0","doc":"","ref":"Fledex.Color.Names.html#red_ncs_/0"},{"type":"function","title":"Fledex.Color.Names.red_orange/0","doc":"","ref":"Fledex.Color.Names.html#red_orange/0"},{"type":"function","title":"Fledex.Color.Names.red_orange_color_wheel_/0","doc":"","ref":"Fledex.Color.Names.html#red_orange_color_wheel_/0"},{"type":"function","title":"Fledex.Color.Names.red_orange_crayola_/0","doc":"","ref":"Fledex.Color.Names.html#red_orange_crayola_/0"},{"type":"function","title":"Fledex.Color.Names.red_pantone_/0","doc":"","ref":"Fledex.Color.Names.html#red_pantone_/0"},{"type":"function","title":"Fledex.Color.Names.red_pigment_/0","doc":"","ref":"Fledex.Color.Names.html#red_pigment_/0"},{"type":"function","title":"Fledex.Color.Names.red_purple/0","doc":"","ref":"Fledex.Color.Names.html#red_purple/0"},{"type":"function","title":"Fledex.Color.Names.red_ryb_/0","doc":"","ref":"Fledex.Color.Names.html#red_ryb_/0"},{"type":"function","title":"Fledex.Color.Names.red_salsa/0","doc":"","ref":"Fledex.Color.Names.html#red_salsa/0"},{"type":"function","title":"Fledex.Color.Names.red_violet/0","doc":"","ref":"Fledex.Color.Names.html#red_violet/0"},{"type":"function","title":"Fledex.Color.Names.red_violet_color_wheel_/0","doc":"","ref":"Fledex.Color.Names.html#red_violet_color_wheel_/0"},{"type":"function","title":"Fledex.Color.Names.red_violet_crayola_/0","doc":"","ref":"Fledex.Color.Names.html#red_violet_crayola_/0"},{"type":"function","title":"Fledex.Color.Names.redwood/0","doc":"","ref":"Fledex.Color.Names.html#redwood/0"},{"type":"function","title":"Fledex.Color.Names.resolution_blue/0","doc":"","ref":"Fledex.Color.Names.html#resolution_blue/0"},{"type":"function","title":"Fledex.Color.Names.rhythm/0","doc":"","ref":"Fledex.Color.Names.html#rhythm/0"},{"type":"function","title":"Fledex.Color.Names.rich_black/0","doc":"","ref":"Fledex.Color.Names.html#rich_black/0"},{"type":"function","title":"Fledex.Color.Names.rich_black_fogra29_/0","doc":"","ref":"Fledex.Color.Names.html#rich_black_fogra29_/0"},{"type":"function","title":"Fledex.Color.Names.rich_black_fogra39_/0","doc":"","ref":"Fledex.Color.Names.html#rich_black_fogra39_/0"},{"type":"function","title":"Fledex.Color.Names.rifle_green/0","doc":"","ref":"Fledex.Color.Names.html#rifle_green/0"},{"type":"function","title":"Fledex.Color.Names.robin_egg_blue/0","doc":"","ref":"Fledex.Color.Names.html#robin_egg_blue/0"},{"type":"function","title":"Fledex.Color.Names.rocket_metallic/0","doc":"","ref":"Fledex.Color.Names.html#rocket_metallic/0"},{"type":"function","title":"Fledex.Color.Names.rojo_spanish_red/0","doc":"","ref":"Fledex.Color.Names.html#rojo_spanish_red/0"},{"type":"function","title":"Fledex.Color.Names.roman_silver/0","doc":"","ref":"Fledex.Color.Names.html#roman_silver/0"},{"type":"function","title":"Fledex.Color.Names.rose/0","doc":"","ref":"Fledex.Color.Names.html#rose/0"},{"type":"function","title":"Fledex.Color.Names.rose_bonbon/0","doc":"","ref":"Fledex.Color.Names.html#rose_bonbon/0"},{"type":"function","title":"Fledex.Color.Names.rose_dust/0","doc":"","ref":"Fledex.Color.Names.html#rose_dust/0"},{"type":"function","title":"Fledex.Color.Names.rose_ebony/0","doc":"","ref":"Fledex.Color.Names.html#rose_ebony/0"},{"type":"function","title":"Fledex.Color.Names.rose_madder/0","doc":"","ref":"Fledex.Color.Names.html#rose_madder/0"},{"type":"function","title":"Fledex.Color.Names.rose_pink/0","doc":"","ref":"Fledex.Color.Names.html#rose_pink/0"},{"type":"function","title":"Fledex.Color.Names.rose_pompadour/0","doc":"","ref":"Fledex.Color.Names.html#rose_pompadour/0"},{"type":"function","title":"Fledex.Color.Names.rose_red/0","doc":"","ref":"Fledex.Color.Names.html#rose_red/0"},{"type":"function","title":"Fledex.Color.Names.rose_taupe/0","doc":"","ref":"Fledex.Color.Names.html#rose_taupe/0"},{"type":"function","title":"Fledex.Color.Names.rose_vale/0","doc":"","ref":"Fledex.Color.Names.html#rose_vale/0"},{"type":"function","title":"Fledex.Color.Names.rosewood/0","doc":"","ref":"Fledex.Color.Names.html#rosewood/0"},{"type":"function","title":"Fledex.Color.Names.rosso_corsa/0","doc":"","ref":"Fledex.Color.Names.html#rosso_corsa/0"},{"type":"function","title":"Fledex.Color.Names.rosy_brown/0","doc":"","ref":"Fledex.Color.Names.html#rosy_brown/0"},{"type":"function","title":"Fledex.Color.Names.royal_blue_dark_/0","doc":"","ref":"Fledex.Color.Names.html#royal_blue_dark_/0"},{"type":"function","title":"Fledex.Color.Names.royal_blue_light_/0","doc":"","ref":"Fledex.Color.Names.html#royal_blue_light_/0"},{"type":"function","title":"Fledex.Color.Names.royal_purple/0","doc":"","ref":"Fledex.Color.Names.html#royal_purple/0"},{"type":"function","title":"Fledex.Color.Names.royal_yellow/0","doc":"","ref":"Fledex.Color.Names.html#royal_yellow/0"},{"type":"function","title":"Fledex.Color.Names.ruber/0","doc":"","ref":"Fledex.Color.Names.html#ruber/0"},{"type":"function","title":"Fledex.Color.Names.rubine_red/0","doc":"","ref":"Fledex.Color.Names.html#rubine_red/0"},{"type":"function","title":"Fledex.Color.Names.ruby/0","doc":"","ref":"Fledex.Color.Names.html#ruby/0"},{"type":"function","title":"Fledex.Color.Names.ruby_red/0","doc":"","ref":"Fledex.Color.Names.html#ruby_red/0"},{"type":"function","title":"Fledex.Color.Names.rufous/0","doc":"","ref":"Fledex.Color.Names.html#rufous/0"},{"type":"function","title":"Fledex.Color.Names.russet/0","doc":"","ref":"Fledex.Color.Names.html#russet/0"},{"type":"function","title":"Fledex.Color.Names.russian_green/0","doc":"","ref":"Fledex.Color.Names.html#russian_green/0"},{"type":"function","title":"Fledex.Color.Names.russian_violet/0","doc":"","ref":"Fledex.Color.Names.html#russian_violet/0"},{"type":"function","title":"Fledex.Color.Names.rust/0","doc":"","ref":"Fledex.Color.Names.html#rust/0"},{"type":"function","title":"Fledex.Color.Names.rusty_red/0","doc":"","ref":"Fledex.Color.Names.html#rusty_red/0"},{"type":"function","title":"Fledex.Color.Names.sacramento_state_green/0","doc":"","ref":"Fledex.Color.Names.html#sacramento_state_green/0"},{"type":"function","title":"Fledex.Color.Names.saddle_brown/0","doc":"","ref":"Fledex.Color.Names.html#saddle_brown/0"},{"type":"function","title":"Fledex.Color.Names.safety_orange/0","doc":"","ref":"Fledex.Color.Names.html#safety_orange/0"},{"type":"function","title":"Fledex.Color.Names.safety_orange_blaze_orange_/0","doc":"","ref":"Fledex.Color.Names.html#safety_orange_blaze_orange_/0"},{"type":"function","title":"Fledex.Color.Names.safety_yellow/0","doc":"","ref":"Fledex.Color.Names.html#safety_yellow/0"},{"type":"function","title":"Fledex.Color.Names.saffron/0","doc":"","ref":"Fledex.Color.Names.html#saffron/0"},{"type":"function","title":"Fledex.Color.Names.sage/0","doc":"","ref":"Fledex.Color.Names.html#sage/0"},{"type":"function","title":"Fledex.Color.Names.salmon/0","doc":"","ref":"Fledex.Color.Names.html#salmon/0"},{"type":"function","title":"Fledex.Color.Names.salmon_pink/0","doc":"","ref":"Fledex.Color.Names.html#salmon_pink/0"},{"type":"function","title":"Fledex.Color.Names.sand/0","doc":"","ref":"Fledex.Color.Names.html#sand/0"},{"type":"function","title":"Fledex.Color.Names.sand_dune/0","doc":"","ref":"Fledex.Color.Names.html#sand_dune/0"},{"type":"function","title":"Fledex.Color.Names.sandy_brown/0","doc":"","ref":"Fledex.Color.Names.html#sandy_brown/0"},{"type":"function","title":"Fledex.Color.Names.sap_green/0","doc":"","ref":"Fledex.Color.Names.html#sap_green/0"},{"type":"function","title":"Fledex.Color.Names.sapphire/0","doc":"","ref":"Fledex.Color.Names.html#sapphire/0"},{"type":"function","title":"Fledex.Color.Names.sapphire_blue/0","doc":"","ref":"Fledex.Color.Names.html#sapphire_blue/0"},{"type":"function","title":"Fledex.Color.Names.sapphire_crayola_/0","doc":"","ref":"Fledex.Color.Names.html#sapphire_crayola_/0"},{"type":"function","title":"Fledex.Color.Names.satin_sheen_gold/0","doc":"","ref":"Fledex.Color.Names.html#satin_sheen_gold/0"},{"type":"function","title":"Fledex.Color.Names.scarlet/0","doc":"","ref":"Fledex.Color.Names.html#scarlet/0"},{"type":"function","title":"Fledex.Color.Names.schauss_pink/0","doc":"","ref":"Fledex.Color.Names.html#schauss_pink/0"},{"type":"function","title":"Fledex.Color.Names.school_bus_yellow/0","doc":"","ref":"Fledex.Color.Names.html#school_bus_yellow/0"},{"type":"function","title":"Fledex.Color.Names.screamin_green/0","doc":"","ref":"Fledex.Color.Names.html#screamin_green/0"},{"type":"function","title":"Fledex.Color.Names.sea_green/0","doc":"","ref":"Fledex.Color.Names.html#sea_green/0"},{"type":"function","title":"Fledex.Color.Names.sea_green_crayola_/0","doc":"","ref":"Fledex.Color.Names.html#sea_green_crayola_/0"},{"type":"function","title":"Fledex.Color.Names.seal_brown/0","doc":"","ref":"Fledex.Color.Names.html#seal_brown/0"},{"type":"function","title":"Fledex.Color.Names.seance/0","doc":"","ref":"Fledex.Color.Names.html#seance/0"},{"type":"function","title":"Fledex.Color.Names.seashell/0","doc":"","ref":"Fledex.Color.Names.html#seashell/0"},{"type":"function","title":"Fledex.Color.Names.secret/0","doc":"","ref":"Fledex.Color.Names.html#secret/0"},{"type":"function","title":"Fledex.Color.Names.selective_yellow/0","doc":"","ref":"Fledex.Color.Names.html#selective_yellow/0"},{"type":"function","title":"Fledex.Color.Names.sepia/0","doc":"","ref":"Fledex.Color.Names.html#sepia/0"},{"type":"function","title":"Fledex.Color.Names.shadow/0","doc":"","ref":"Fledex.Color.Names.html#shadow/0"},{"type":"function","title":"Fledex.Color.Names.shadow_blue/0","doc":"","ref":"Fledex.Color.Names.html#shadow_blue/0"},{"type":"function","title":"Fledex.Color.Names.shamrock_green/0","doc":"","ref":"Fledex.Color.Names.html#shamrock_green/0"},{"type":"function","title":"Fledex.Color.Names.sheen_green/0","doc":"","ref":"Fledex.Color.Names.html#sheen_green/0"},{"type":"function","title":"Fledex.Color.Names.shimmering_blush/0","doc":"","ref":"Fledex.Color.Names.html#shimmering_blush/0"},{"type":"function","title":"Fledex.Color.Names.shiny_shamrock/0","doc":"","ref":"Fledex.Color.Names.html#shiny_shamrock/0"},{"type":"function","title":"Fledex.Color.Names.shocking_pink/0","doc":"","ref":"Fledex.Color.Names.html#shocking_pink/0"},{"type":"function","title":"Fledex.Color.Names.shocking_pink_crayola_/0","doc":"","ref":"Fledex.Color.Names.html#shocking_pink_crayola_/0"},{"type":"function","title":"Fledex.Color.Names.sienna/0","doc":"","ref":"Fledex.Color.Names.html#sienna/0"},{"type":"function","title":"Fledex.Color.Names.silver/0","doc":"","ref":"Fledex.Color.Names.html#silver/0"},{"type":"function","title":"Fledex.Color.Names.silver_chalice/0","doc":"","ref":"Fledex.Color.Names.html#silver_chalice/0"},{"type":"function","title":"Fledex.Color.Names.silver_crayola_/0","doc":"","ref":"Fledex.Color.Names.html#silver_crayola_/0"},{"type":"function","title":"Fledex.Color.Names.silver_metallic_/0","doc":"","ref":"Fledex.Color.Names.html#silver_metallic_/0"},{"type":"function","title":"Fledex.Color.Names.silver_pink/0","doc":"","ref":"Fledex.Color.Names.html#silver_pink/0"},{"type":"function","title":"Fledex.Color.Names.silver_sand/0","doc":"","ref":"Fledex.Color.Names.html#silver_sand/0"},{"type":"function","title":"Fledex.Color.Names.sinopia/0","doc":"","ref":"Fledex.Color.Names.html#sinopia/0"},{"type":"function","title":"Fledex.Color.Names.sizzling_red/0","doc":"","ref":"Fledex.Color.Names.html#sizzling_red/0"},{"type":"function","title":"Fledex.Color.Names.sizzling_sunrise/0","doc":"","ref":"Fledex.Color.Names.html#sizzling_sunrise/0"},{"type":"function","title":"Fledex.Color.Names.skobeloff/0","doc":"","ref":"Fledex.Color.Names.html#skobeloff/0"},{"type":"function","title":"Fledex.Color.Names.sky_blue/0","doc":"","ref":"Fledex.Color.Names.html#sky_blue/0"},{"type":"function","title":"Fledex.Color.Names.sky_blue_crayola_/0","doc":"","ref":"Fledex.Color.Names.html#sky_blue_crayola_/0"},{"type":"function","title":"Fledex.Color.Names.sky_magenta/0","doc":"","ref":"Fledex.Color.Names.html#sky_magenta/0"},{"type":"function","title":"Fledex.Color.Names.slate_blue/0","doc":"","ref":"Fledex.Color.Names.html#slate_blue/0"},{"type":"function","title":"Fledex.Color.Names.slate_gray/0","doc":"","ref":"Fledex.Color.Names.html#slate_gray/0"},{"type":"function","title":"Fledex.Color.Names.slimy_green/0","doc":"","ref":"Fledex.Color.Names.html#slimy_green/0"},{"type":"function","title":"Fledex.Color.Names.smitten/0","doc":"","ref":"Fledex.Color.Names.html#smitten/0"},{"type":"function","title":"Fledex.Color.Names.smoky_black/0","doc":"","ref":"Fledex.Color.Names.html#smoky_black/0"},{"type":"function","title":"Fledex.Color.Names.snow/0","doc":"","ref":"Fledex.Color.Names.html#snow/0"},{"type":"function","title":"Fledex.Color.Names.solid_pink/0","doc":"","ref":"Fledex.Color.Names.html#solid_pink/0"},{"type":"function","title":"Fledex.Color.Names.sonic_silver/0","doc":"","ref":"Fledex.Color.Names.html#sonic_silver/0"},{"type":"function","title":"Fledex.Color.Names.space_cadet/0","doc":"","ref":"Fledex.Color.Names.html#space_cadet/0"},{"type":"function","title":"Fledex.Color.Names.spanish_bistre/0","doc":"","ref":"Fledex.Color.Names.html#spanish_bistre/0"},{"type":"function","title":"Fledex.Color.Names.spanish_blue/0","doc":"","ref":"Fledex.Color.Names.html#spanish_blue/0"},{"type":"function","title":"Fledex.Color.Names.spanish_carmine/0","doc":"","ref":"Fledex.Color.Names.html#spanish_carmine/0"},{"type":"function","title":"Fledex.Color.Names.spanish_gray/0","doc":"","ref":"Fledex.Color.Names.html#spanish_gray/0"},{"type":"function","title":"Fledex.Color.Names.spanish_green/0","doc":"","ref":"Fledex.Color.Names.html#spanish_green/0"},{"type":"function","title":"Fledex.Color.Names.spanish_orange/0","doc":"","ref":"Fledex.Color.Names.html#spanish_orange/0"},{"type":"function","title":"Fledex.Color.Names.spanish_pink/0","doc":"","ref":"Fledex.Color.Names.html#spanish_pink/0"},{"type":"function","title":"Fledex.Color.Names.spanish_red/0","doc":"","ref":"Fledex.Color.Names.html#spanish_red/0"},{"type":"function","title":"Fledex.Color.Names.spanish_sky_blue/0","doc":"","ref":"Fledex.Color.Names.html#spanish_sky_blue/0"},{"type":"function","title":"Fledex.Color.Names.spanish_violet/0","doc":"","ref":"Fledex.Color.Names.html#spanish_violet/0"},{"type":"function","title":"Fledex.Color.Names.spanish_viridian/0","doc":"","ref":"Fledex.Color.Names.html#spanish_viridian/0"},{"type":"function","title":"Fledex.Color.Names.spring_bud/0","doc":"","ref":"Fledex.Color.Names.html#spring_bud/0"},{"type":"function","title":"Fledex.Color.Names.spring_frost/0","doc":"","ref":"Fledex.Color.Names.html#spring_frost/0"},{"type":"function","title":"Fledex.Color.Names.spring_green/0","doc":"","ref":"Fledex.Color.Names.html#spring_green/0"},{"type":"function","title":"Fledex.Color.Names.spring_green_crayola_/0","doc":"","ref":"Fledex.Color.Names.html#spring_green_crayola_/0"},{"type":"function","title":"Fledex.Color.Names.st_patrick_s_blue/0","doc":"","ref":"Fledex.Color.Names.html#st_patrick_s_blue/0"},{"type":"function","title":"Fledex.Color.Names.star_command_blue/0","doc":"","ref":"Fledex.Color.Names.html#star_command_blue/0"},{"type":"function","title":"Fledex.Color.Names.steel_blue/0","doc":"","ref":"Fledex.Color.Names.html#steel_blue/0"},{"type":"function","title":"Fledex.Color.Names.steel_pink/0","doc":"","ref":"Fledex.Color.Names.html#steel_pink/0"},{"type":"function","title":"Fledex.Color.Names.stil_de_grain_yellow/0","doc":"","ref":"Fledex.Color.Names.html#stil_de_grain_yellow/0"},{"type":"function","title":"Fledex.Color.Names.straw/0","doc":"","ref":"Fledex.Color.Names.html#straw/0"},{"type":"function","title":"Fledex.Color.Names.strawberry/0","doc":"","ref":"Fledex.Color.Names.html#strawberry/0"},{"type":"function","title":"Fledex.Color.Names.strawberry_blonde/0","doc":"","ref":"Fledex.Color.Names.html#strawberry_blonde/0"},{"type":"function","title":"Fledex.Color.Names.strong_lime_green/0","doc":"","ref":"Fledex.Color.Names.html#strong_lime_green/0"},{"type":"function","title":"Fledex.Color.Names.sugar_plum/0","doc":"","ref":"Fledex.Color.Names.html#sugar_plum/0"},{"type":"function","title":"Fledex.Color.Names.sunglow/0","doc":"","ref":"Fledex.Color.Names.html#sunglow/0"},{"type":"function","title":"Fledex.Color.Names.sunray/0","doc":"","ref":"Fledex.Color.Names.html#sunray/0"},{"type":"function","title":"Fledex.Color.Names.sunset/0","doc":"","ref":"Fledex.Color.Names.html#sunset/0"},{"type":"function","title":"Fledex.Color.Names.super_pink/0","doc":"","ref":"Fledex.Color.Names.html#super_pink/0"},{"type":"function","title":"Fledex.Color.Names.sweet_brown/0","doc":"","ref":"Fledex.Color.Names.html#sweet_brown/0"},{"type":"function","title":"Fledex.Color.Names.syracuse_orange/0","doc":"","ref":"Fledex.Color.Names.html#syracuse_orange/0"},{"type":"function","title":"Fledex.Color.Names.tan/0","doc":"","ref":"Fledex.Color.Names.html#tan/0"},{"type":"function","title":"Fledex.Color.Names.tan_crayola_/0","doc":"","ref":"Fledex.Color.Names.html#tan_crayola_/0"},{"type":"function","title":"Fledex.Color.Names.tangerine/0","doc":"","ref":"Fledex.Color.Names.html#tangerine/0"},{"type":"function","title":"Fledex.Color.Names.tango_pink/0","doc":"","ref":"Fledex.Color.Names.html#tango_pink/0"},{"type":"function","title":"Fledex.Color.Names.tart_orange/0","doc":"","ref":"Fledex.Color.Names.html#tart_orange/0"},{"type":"function","title":"Fledex.Color.Names.taupe/0","doc":"","ref":"Fledex.Color.Names.html#taupe/0"},{"type":"function","title":"Fledex.Color.Names.taupe_gray/0","doc":"","ref":"Fledex.Color.Names.html#taupe_gray/0"},{"type":"function","title":"Fledex.Color.Names.tea_green/0","doc":"","ref":"Fledex.Color.Names.html#tea_green/0"},{"type":"function","title":"Fledex.Color.Names.tea_rose/0","doc":"","ref":"Fledex.Color.Names.html#tea_rose/0"},{"type":"function","title":"Fledex.Color.Names.teal/0","doc":"","ref":"Fledex.Color.Names.html#teal/0"},{"type":"function","title":"Fledex.Color.Names.teal_blue/0","doc":"","ref":"Fledex.Color.Names.html#teal_blue/0"},{"type":"function","title":"Fledex.Color.Names.telemagenta/0","doc":"","ref":"Fledex.Color.Names.html#telemagenta/0"},{"type":"function","title":"Fledex.Color.Names.tenne_tawny_/0","doc":"","ref":"Fledex.Color.Names.html#tenne_tawny_/0"},{"type":"function","title":"Fledex.Color.Names.terra_cotta/0","doc":"","ref":"Fledex.Color.Names.html#terra_cotta/0"},{"type":"function","title":"Fledex.Color.Names.thistle/0","doc":"","ref":"Fledex.Color.Names.html#thistle/0"},{"type":"function","title":"Fledex.Color.Names.thulian_pink/0","doc":"","ref":"Fledex.Color.Names.html#thulian_pink/0"},{"type":"function","title":"Fledex.Color.Names.tickle_me_pink/0","doc":"","ref":"Fledex.Color.Names.html#tickle_me_pink/0"},{"type":"function","title":"Fledex.Color.Names.tiffany_blue/0","doc":"","ref":"Fledex.Color.Names.html#tiffany_blue/0"},{"type":"function","title":"Fledex.Color.Names.timberwolf/0","doc":"","ref":"Fledex.Color.Names.html#timberwolf/0"},{"type":"function","title":"Fledex.Color.Names.titanium_yellow/0","doc":"","ref":"Fledex.Color.Names.html#titanium_yellow/0"},{"type":"function","title":"Fledex.Color.Names.tomato/0","doc":"","ref":"Fledex.Color.Names.html#tomato/0"},{"type":"function","title":"Fledex.Color.Names.tourmaline/0","doc":"","ref":"Fledex.Color.Names.html#tourmaline/0"},{"type":"function","title":"Fledex.Color.Names.tropical_rainforest/0","doc":"","ref":"Fledex.Color.Names.html#tropical_rainforest/0"},{"type":"function","title":"Fledex.Color.Names.true_blue/0","doc":"","ref":"Fledex.Color.Names.html#true_blue/0"},{"type":"function","title":"Fledex.Color.Names.trypan_blue/0","doc":"","ref":"Fledex.Color.Names.html#trypan_blue/0"},{"type":"function","title":"Fledex.Color.Names.tufts_blue/0","doc":"","ref":"Fledex.Color.Names.html#tufts_blue/0"},{"type":"function","title":"Fledex.Color.Names.tumbleweed/0","doc":"","ref":"Fledex.Color.Names.html#tumbleweed/0"},{"type":"function","title":"Fledex.Color.Names.turquoise/0","doc":"","ref":"Fledex.Color.Names.html#turquoise/0"},{"type":"function","title":"Fledex.Color.Names.turquoise_blue/0","doc":"","ref":"Fledex.Color.Names.html#turquoise_blue/0"},{"type":"function","title":"Fledex.Color.Names.turquoise_green/0","doc":"","ref":"Fledex.Color.Names.html#turquoise_green/0"},{"type":"function","title":"Fledex.Color.Names.turtle_green/0","doc":"","ref":"Fledex.Color.Names.html#turtle_green/0"},{"type":"function","title":"Fledex.Color.Names.tuscan/0","doc":"","ref":"Fledex.Color.Names.html#tuscan/0"},{"type":"function","title":"Fledex.Color.Names.tuscan_brown/0","doc":"","ref":"Fledex.Color.Names.html#tuscan_brown/0"},{"type":"function","title":"Fledex.Color.Names.tuscan_red/0","doc":"","ref":"Fledex.Color.Names.html#tuscan_red/0"},{"type":"function","title":"Fledex.Color.Names.tuscan_tan/0","doc":"","ref":"Fledex.Color.Names.html#tuscan_tan/0"},{"type":"function","title":"Fledex.Color.Names.tuscany/0","doc":"","ref":"Fledex.Color.Names.html#tuscany/0"},{"type":"function","title":"Fledex.Color.Names.twilight_lavender/0","doc":"","ref":"Fledex.Color.Names.html#twilight_lavender/0"},{"type":"function","title":"Fledex.Color.Names.tyrian_purple/0","doc":"","ref":"Fledex.Color.Names.html#tyrian_purple/0"},{"type":"function","title":"Fledex.Color.Names.ua_blue/0","doc":"","ref":"Fledex.Color.Names.html#ua_blue/0"},{"type":"function","title":"Fledex.Color.Names.ua_red/0","doc":"","ref":"Fledex.Color.Names.html#ua_red/0"},{"type":"function","title":"Fledex.Color.Names.ultra_pink/0","doc":"","ref":"Fledex.Color.Names.html#ultra_pink/0"},{"type":"function","title":"Fledex.Color.Names.ultra_red/0","doc":"","ref":"Fledex.Color.Names.html#ultra_red/0"},{"type":"function","title":"Fledex.Color.Names.ultramarine/0","doc":"","ref":"Fledex.Color.Names.html#ultramarine/0"},{"type":"function","title":"Fledex.Color.Names.ultramarine_blue/0","doc":"","ref":"Fledex.Color.Names.html#ultramarine_blue/0"},{"type":"function","title":"Fledex.Color.Names.umber/0","doc":"","ref":"Fledex.Color.Names.html#umber/0"},{"type":"function","title":"Fledex.Color.Names.unbleached_silk/0","doc":"","ref":"Fledex.Color.Names.html#unbleached_silk/0"},{"type":"function","title":"Fledex.Color.Names.united_nations_blue/0","doc":"","ref":"Fledex.Color.Names.html#united_nations_blue/0"},{"type":"function","title":"Fledex.Color.Names.university_of_pennsylvania_red/0","doc":"","ref":"Fledex.Color.Names.html#university_of_pennsylvania_red/0"},{"type":"function","title":"Fledex.Color.Names.unmellow_yellow/0","doc":"","ref":"Fledex.Color.Names.html#unmellow_yellow/0"},{"type":"function","title":"Fledex.Color.Names.up_forest_green/0","doc":"","ref":"Fledex.Color.Names.html#up_forest_green/0"},{"type":"function","title":"Fledex.Color.Names.up_maroon/0","doc":"","ref":"Fledex.Color.Names.html#up_maroon/0"},{"type":"function","title":"Fledex.Color.Names.upsdell_red/0","doc":"","ref":"Fledex.Color.Names.html#upsdell_red/0"},{"type":"function","title":"Fledex.Color.Names.uranian_blue/0","doc":"","ref":"Fledex.Color.Names.html#uranian_blue/0"},{"type":"function","title":"Fledex.Color.Names.usafa_blue/0","doc":"","ref":"Fledex.Color.Names.html#usafa_blue/0"},{"type":"function","title":"Fledex.Color.Names.van_dyke_brown/0","doc":"","ref":"Fledex.Color.Names.html#van_dyke_brown/0"},{"type":"function","title":"Fledex.Color.Names.vanilla/0","doc":"","ref":"Fledex.Color.Names.html#vanilla/0"},{"type":"function","title":"Fledex.Color.Names.vanilla_ice/0","doc":"","ref":"Fledex.Color.Names.html#vanilla_ice/0"},{"type":"function","title":"Fledex.Color.Names.vegas_gold/0","doc":"","ref":"Fledex.Color.Names.html#vegas_gold/0"},{"type":"function","title":"Fledex.Color.Names.venetian_red/0","doc":"","ref":"Fledex.Color.Names.html#venetian_red/0"},{"type":"function","title":"Fledex.Color.Names.verdigris/0","doc":"","ref":"Fledex.Color.Names.html#verdigris/0"},{"type":"function","title":"Fledex.Color.Names.vermilion2/0","doc":"","ref":"Fledex.Color.Names.html#vermilion2/0"},{"type":"function","title":"Fledex.Color.Names.vermilion/0","doc":"","ref":"Fledex.Color.Names.html#vermilion/0"},{"type":"function","title":"Fledex.Color.Names.veronica/0","doc":"","ref":"Fledex.Color.Names.html#veronica/0"},{"type":"function","title":"Fledex.Color.Names.violet/0","doc":"","ref":"Fledex.Color.Names.html#violet/0"},{"type":"function","title":"Fledex.Color.Names.violet_blue/0","doc":"","ref":"Fledex.Color.Names.html#violet_blue/0"},{"type":"function","title":"Fledex.Color.Names.violet_blue_crayola_/0","doc":"","ref":"Fledex.Color.Names.html#violet_blue_crayola_/0"},{"type":"function","title":"Fledex.Color.Names.violet_color_wheel_/0","doc":"","ref":"Fledex.Color.Names.html#violet_color_wheel_/0"},{"type":"function","title":"Fledex.Color.Names.violet_crayola_/0","doc":"","ref":"Fledex.Color.Names.html#violet_crayola_/0"},{"type":"function","title":"Fledex.Color.Names.violet_red/0","doc":"","ref":"Fledex.Color.Names.html#violet_red/0"},{"type":"function","title":"Fledex.Color.Names.violet_red_perbang_/0","doc":"","ref":"Fledex.Color.Names.html#violet_red_perbang_/0"},{"type":"function","title":"Fledex.Color.Names.violet_ryb_/0","doc":"","ref":"Fledex.Color.Names.html#violet_ryb_/0"},{"type":"function","title":"Fledex.Color.Names.violet_web_/0","doc":"","ref":"Fledex.Color.Names.html#violet_web_/0"},{"type":"function","title":"Fledex.Color.Names.viridian/0","doc":"","ref":"Fledex.Color.Names.html#viridian/0"},{"type":"function","title":"Fledex.Color.Names.viridian_green/0","doc":"","ref":"Fledex.Color.Names.html#viridian_green/0"},{"type":"function","title":"Fledex.Color.Names.vivid_burgundy/0","doc":"","ref":"Fledex.Color.Names.html#vivid_burgundy/0"},{"type":"function","title":"Fledex.Color.Names.vivid_sky_blue/0","doc":"","ref":"Fledex.Color.Names.html#vivid_sky_blue/0"},{"type":"function","title":"Fledex.Color.Names.vivid_tangerine/0","doc":"","ref":"Fledex.Color.Names.html#vivid_tangerine/0"},{"type":"function","title":"Fledex.Color.Names.vivid_violet/0","doc":"","ref":"Fledex.Color.Names.html#vivid_violet/0"},{"type":"function","title":"Fledex.Color.Names.volt/0","doc":"","ref":"Fledex.Color.Names.html#volt/0"},{"type":"function","title":"Fledex.Color.Names.warm_black/0","doc":"","ref":"Fledex.Color.Names.html#warm_black/0"},{"type":"function","title":"Fledex.Color.Names.weezy_blue/0","doc":"","ref":"Fledex.Color.Names.html#weezy_blue/0"},{"type":"function","title":"Fledex.Color.Names.wheat/0","doc":"","ref":"Fledex.Color.Names.html#wheat/0"},{"type":"function","title":"Fledex.Color.Names.white/0","doc":"","ref":"Fledex.Color.Names.html#white/0"},{"type":"function","title":"Fledex.Color.Names.wild_blue_yonder/0","doc":"","ref":"Fledex.Color.Names.html#wild_blue_yonder/0"},{"type":"function","title":"Fledex.Color.Names.wild_orchid/0","doc":"","ref":"Fledex.Color.Names.html#wild_orchid/0"},{"type":"function","title":"Fledex.Color.Names.wild_strawberry/0","doc":"","ref":"Fledex.Color.Names.html#wild_strawberry/0"},{"type":"function","title":"Fledex.Color.Names.wild_watermelon/0","doc":"","ref":"Fledex.Color.Names.html#wild_watermelon/0"},{"type":"function","title":"Fledex.Color.Names.windsor_tan/0","doc":"","ref":"Fledex.Color.Names.html#windsor_tan/0"},{"type":"function","title":"Fledex.Color.Names.wine/0","doc":"","ref":"Fledex.Color.Names.html#wine/0"},{"type":"function","title":"Fledex.Color.Names.wine_dregs/0","doc":"","ref":"Fledex.Color.Names.html#wine_dregs/0"},{"type":"function","title":"Fledex.Color.Names.winter_sky/0","doc":"","ref":"Fledex.Color.Names.html#winter_sky/0"},{"type":"function","title":"Fledex.Color.Names.wintergreen_dream/0","doc":"","ref":"Fledex.Color.Names.html#wintergreen_dream/0"},{"type":"function","title":"Fledex.Color.Names.wisteria/0","doc":"","ref":"Fledex.Color.Names.html#wisteria/0"},{"type":"function","title":"Fledex.Color.Names.wood_brown/0","doc":"","ref":"Fledex.Color.Names.html#wood_brown/0"},{"type":"function","title":"Fledex.Color.Names.xanadu/0","doc":"","ref":"Fledex.Color.Names.html#xanadu/0"},{"type":"function","title":"Fledex.Color.Names.xanthic/0","doc":"","ref":"Fledex.Color.Names.html#xanthic/0"},{"type":"function","title":"Fledex.Color.Names.xanthous/0","doc":"","ref":"Fledex.Color.Names.html#xanthous/0"},{"type":"function","title":"Fledex.Color.Names.yale_blue/0","doc":"","ref":"Fledex.Color.Names.html#yale_blue/0"},{"type":"function","title":"Fledex.Color.Names.yellow/0","doc":"","ref":"Fledex.Color.Names.html#yellow/0"},{"type":"function","title":"Fledex.Color.Names.yellow_crayola_/0","doc":"","ref":"Fledex.Color.Names.html#yellow_crayola_/0"},{"type":"function","title":"Fledex.Color.Names.yellow_green/0","doc":"","ref":"Fledex.Color.Names.html#yellow_green/0"},{"type":"function","title":"Fledex.Color.Names.yellow_green_color_wheel_/0","doc":"","ref":"Fledex.Color.Names.html#yellow_green_color_wheel_/0"},{"type":"function","title":"Fledex.Color.Names.yellow_green_crayola_/0","doc":"","ref":"Fledex.Color.Names.html#yellow_green_crayola_/0"},{"type":"function","title":"Fledex.Color.Names.yellow_munsell_/0","doc":"","ref":"Fledex.Color.Names.html#yellow_munsell_/0"},{"type":"function","title":"Fledex.Color.Names.yellow_ncs_/0","doc":"","ref":"Fledex.Color.Names.html#yellow_ncs_/0"},{"type":"function","title":"Fledex.Color.Names.yellow_orange/0","doc":"","ref":"Fledex.Color.Names.html#yellow_orange/0"},{"type":"function","title":"Fledex.Color.Names.yellow_orange_color_wheel_/0","doc":"","ref":"Fledex.Color.Names.html#yellow_orange_color_wheel_/0"},{"type":"function","title":"Fledex.Color.Names.yellow_pantone_/0","doc":"","ref":"Fledex.Color.Names.html#yellow_pantone_/0"},{"type":"function","title":"Fledex.Color.Names.yellow_process_/0","doc":"","ref":"Fledex.Color.Names.html#yellow_process_/0"},{"type":"function","title":"Fledex.Color.Names.yellow_ryb_/0","doc":"","ref":"Fledex.Color.Names.html#yellow_ryb_/0"},{"type":"function","title":"Fledex.Color.Names.yellow_sunshine/0","doc":"","ref":"Fledex.Color.Names.html#yellow_sunshine/0"},{"type":"function","title":"Fledex.Color.Names.yinmn_blue/0","doc":"","ref":"Fledex.Color.Names.html#yinmn_blue/0"},{"type":"function","title":"Fledex.Color.Names.zaffre/0","doc":"","ref":"Fledex.Color.Names.html#zaffre/0"},{"type":"function","title":"Fledex.Color.Names.zomp/0","doc":"","ref":"Fledex.Color.Names.html#zomp/0"},{"type":"module","title":"Fledex.Color.Types","doc":"","ref":"Fledex.Color.Types.html"},{"type":"type","title":"Fledex.Color.Types.colorint/0","doc":"","ref":"Fledex.Color.Types.html#t:colorint/0"},{"type":"type","title":"Fledex.Color.Types.hsv/0","doc":"","ref":"Fledex.Color.Types.html#t:hsv/0"},{"type":"type","title":"Fledex.Color.Types.rgb/0","doc":"","ref":"Fledex.Color.Types.html#t:rgb/0"},{"type":"module","title":"Fledex.Color.Utils","doc":"Most functions are reimplementations from FastLED. Here is a detailed\nexplanation of those functions:\nhttps://github.com/FastLED/FastLED/wiki/High-performance-math","ref":"Fledex.Color.Utils.html"},{"type":"function","title":"Fledex.Color.Utils.add_subpixels/1","doc":"This function adds the given subpixels `[{r1, g1, b1}, {r2, g2, b2}, ...]` together.\nThe result {r1+r2+..., g1+g2+..., b1+b2+...} is probably outside of the standard\n8bit range and will have to be rescaled","ref":"Fledex.Color.Utils.html#add_subpixels/1"},{"type":"function","title":"Fledex.Color.Utils.avg/1","doc":"This function calculates the average of the given \"rgb\" values","ref":"Fledex.Color.Utils.html#avg/1"},{"type":"function","title":"Fledex.Color.Utils.cap/2","doc":"This function combines (adds) the given rgb values and caps them to the given range\n(by default 0..255)","ref":"Fledex.Color.Utils.html#cap/2"},{"type":"function","title":"Fledex.Color.Utils.combine_subpixels/1","doc":"This function combines the subpixels to a single (color) integer value","ref":"Fledex.Color.Utils.html#combine_subpixels/1"},{"type":"function","title":"Fledex.Color.Utils.convert_to_subpixels/1","doc":"This function splits a single (color) integer value into it's rgb components","ref":"Fledex.Color.Utils.html#convert_to_subpixels/1"},{"type":"function","title":"Fledex.Color.Utils.frac8/2","doc":"calculate a fraction mapped to a 8bit range","ref":"Fledex.Color.Utils.html#frac8/2"},{"type":"function","title":"Fledex.Color.Utils.nscale8/3","doc":"same as #scale8, except that it does it for all 3 rgb value\nat the same time.","ref":"Fledex.Color.Utils.html#nscale8/3"},{"type":"function","title":"Fledex.Color.Utils.scale8/3","doc":"This function scales a value into a specific range. the video parameter\nindicates whether the returned value should be correct to not return 0","ref":"Fledex.Color.Utils.html#scale8/3"},{"type":"function","title":"Fledex.Color.Utils.split_into_subpixels/1","doc":"Splits the rgb-integer value into it's subpixels and returns an\n`{r, g, b}` tupel","ref":"Fledex.Color.Utils.html#split_into_subpixels/1"},{"type":"extras","title":"Fledex","doc":"# Fledex\n\nFledex is a small [Elixir](https://elixir-lang.org/) library It really is intended for educational purposes.\nIt is written for a RaspberryPi Zero W running [Nerves](https://nerves-project.org/) especially with a [Nerves-Livebook](https://hexdocs.pm/nerves/getting-started.html#nerves-livebook). \nThe intent of the library is to simplify the programming of a programmable LED strip (currently based on a [WS2801 chip](https://cdn-shop.adafruit.com/datasheets/WS2801.pdf)) and thereby to make it accessible even for kids.\n\nThe idea is to introduce similarly easy concepts for the programming of LEDs as [SonicPi](https://sonic-pi.net/) did for music. The library was developped in collaboration with my son and hopefully we can push it to become better over time. For my son the goal will be to connect the LEDs to some music and to animate the LEDs depending on the beat.\n\nQuite a lot of inspiration came from the [FastLED project](http://fastled.io/) and quite a few of their functions got reimplemented in Elixir. If you look at the implementation of some of those functions you might want to look at their comments.","ref":"readme-1.html"},{"type":"extras","title":"Installation - Fledex","doc":"The library is [available in Hex](https://hex.pm/packages/fledex), the package can be installed\nby adding `:fledex` to your list of dependencies in `mix.exs`:\n\n```elixir\ndef deps do\n  [\n    {:fledex, \"~> 0.2.0\"}\n  ]\nend\n```\n\nOnce in you have installed the library and run your usual `mix deps.get` you can start the LedDriver Server by calling:\n```elixir\nconfig = %{\n  # here comes your configuration\n}\n{:ok, pid} = LedsDriver.start_link(config)\n```\n\nThe LedsDriver should have quite reasonable defaults to get you started (a LoggerDriver is used by default)\n\nYour interaction with the LedDriver should mainly happen through the Leds module. To set the first 3 LEDs (of a 50 LED strip) to red, green and blue you would do the following (here the [color names](https://www.ditig.com/256-colors-cheat-sheet) are used, but you could have used the hex values `0xFF0000`, `0x00FF00`, and `0x0000FF` too):\n```elixir\nLedsDriver.define_namespace(:default)\nLeds.leds(50)\n  |> Leds.light(:red)\n  |> Leds.light(:green1) \n  |> Leds.light(:blue)\n  |> Leds.send() # :default namespace is used as default\n```\nAll other LEDs would be set to off\n\nThe above approach is rather cumbersome with a lot of LEDs, and would be even more difficult if you want to animate it. Thus, instead of managing the LED strip yourself, you should use the FLedex DSL.\n\nTake a look at the [Livebook examples](README.md#livebook) on how to use the DSL","ref":"readme-1.html#installation"},{"type":"extras","title":"Livebook - Fledex","doc":"You can find some [livebooks](livebooks/README.md) files that show you how to use the library in a notebook (with and without hardware). You should be able to do most of your development on a computer (emulating the LED strip with a KinoDriver) before adjusting it to the real hardware (with the SpiDriver). On real hardware you can even run it with serveral drivers at the same time.","ref":"readme-1.html#livebook"},{"type":"extras","title":"Known Limitations - Fledex","doc":"If you want to run this library in nerves-livebook, you currently have to compile your own livebook with the library included in your `mix.exs` file, since you can't add any libraries that are not already bundled.","ref":"readme-1.html#known-limitations"},{"type":"extras","title":"Overview","doc":"# Overview\nThis document gives a rough overview over the architecture of Fledex. We first will look at the low level aspects (the different drivers) and then work our way up the stack.\n\n![Architecture Diagram](./architecture.drawio.png)\n\n# The drivers\nThe main interface to talk to the \"hardware\" is the `LedsDriver`. It takes the `Leds` definitions merges the different definitions and then passes it on to the actual hardware. It plays about the same role as a window server in operating system.\n\nThe `LedsDriver` allows to define serveral namespaces that can have their own led definitions and that are only merged together at \"display\" time. This is similar in defining several windows in a window server. They also all end up on the same display.\n\nThe `LedsDriver` does not really know how to talk to the actual hardware, but leaves this to the hardware spectific `Driver`s. It's possible to register several drivers at the same time.\n\nCurrently there are 4 drivers available:\n* `SpiDriver` is the main driver for talking to a real [led strip with a ws2801 chip](https://www.amazon.com/s?k=ws2801) over the spi bus\n* `KinoDriver` is a driver that is very convenient when working with a [Livebook](https://livebook.dev/) to emulate an led strip.\n* `LoggerDriver` is a driver that dumps the data to a logger.\n* `NullDriver` is a driver that acts similar to `/dev/null`, i.e. doesn't do anyting with the data. This can be very convenient for running some tests.\n\n# The Leds\nThe `Leds` is an easy way to define a set of Leds. This module provides the possibility to specify individual leds by integer/name/rgb-values, by a generator function (like `:rainbow`, or `:gradient`), or by combining various `Leds` definitions into a single definition.\n\nThe `Leds` are not bound to a specific led strip (and namespace), but can be send to one by calling the `send()` function with the appropriate parameters. For convenience it's possible to bind it already during creation time to a specific led strip and namespace.\n\n# The Animations\nTo define individual `Leds` is nice, but it would be even nicer, if it would be possible to animate the `Leds`. This is where the LedAnimator comes in. It allows to define `Leds` and vary them through some triggers (like a timer/counter). \nIt's possible to define this simply through a sequence of `Leds` definitions followed by a `send()` and some `Process.sleep()`, but that approach would have several limitations.\n\nThe `LedAnimator` is a `GenServer` that loops through the animation function and allows to modify the animation between loops.\n\nThe various `LedAnimator`s can be managed through a `LedAnimationManager`. It allows to create, redefine, and destroy animations (i.e.`LedAnimator`s) through a single configuration.\n\n# The Fledex DSL\nThe ultimate goal is to define a `Fledex` DSL that can configure the `LedAnimationManager` and update annimations on the fly.\n\nIn the above diagram an example is shown on how such a DSL might look like. \n\n# The Triggers\n\nThe `LedsDriver` is publishing via `PubSub` an event (a trigger) that gets picked up by the `LedAnimator`s to change their animation. The trigger can not only be created by the driver, but also by external events. The difference is that only the triggers from the driver are used by the `LedAnimator`s to redefine the animation. All other triggers are collected over time and can be used when updating the animation. \n\nFor example: we want to be able to check the current temperature in regular interval and trigger a re-animation to adjust the \"display\" depending on the temperature.\n\n# Final Notes","ref":"architecture.html"},{"type":"extras","title":"Naming - Overview","doc":"The led naming, the namespace naming, and the `LedsDriver` server naming should all be driven by the `Fledex`  DSL. Even though it would be possible to have different names it helps to align them. The `led_strip` name becomes the `LedsDriver` server name. The `live_loop` name becomes the namespace name and combined with the `led_strip` name the `LedAnimator` server name.","ref":"architecture.html#naming"},{"type":"extras","title":"Intro","doc":"# Intro\nThis is a description of the livebooks in this folder. The examples are structured in such a way that we slowly walk up the abstraction stack. From very low level to a high level language. If are not interested in the technical details, the motivations, and the decisions then you probably want to only look livebook [#1](livebooks/README.md#1-first-steps-with-an-led-strip) (to set up your LED strip correctly) and [#6](livebooks/README.md#6-fledex-dsl) (to define your animations). Only the whole set will give you, however, a good overview.\n\nIt is recommended that you look at the different livebooks in parallel to the [Architecture Overview](../docs/architecture.md).\n\n# 1. First steps with an LED strip\nThe first livebook has nothing to do with the Fledex library, but describes on how to set up the [RaspberryPi](https://www.raspberrypi.org/), how to connect the LED strip to it and how we can communicate with it via the SPI bus. It also shows how easy it is to communicate to an LED strip. At the same time it is cumbersome, due the sheer number of LEDs that can be addressed. This example is good to\n\n- ensure that everything everything is set up correctly (before we bring the complexity of a library in)\n- get an understanding on why Fledex was created in the first place to make the definition of the strip easier\n\nWe don't really want to work on this level\n\n# 2. Fledex: First steps\nThe first steps with the Fledex library. The example shows how the LED strip can be emulated with\nthe Kino driver, but it does contain commented out code for the SPI driver too to send it to a\nreal LED strip.\nIn the driver configs we define an error correction, since the 5050 chips have too intensive green\nand blue LEDs that need to be compensated to have a more natural look. The Kino driver does not\nrequire such a compensation, even though it is possible to define one too.\nBy changing the definition of our LEDs we can also create some simple animations\n\nThis example works still on a very low level, one that we do not want use. \n\n# 3. Fledex: Animations\nIn this livebook we look how animations can be defined, this is the next step(s) above the `LedsDriver`. The `LedAnimationManager` is the level that we want to operate on and the following examples will use what we have explored here and will create some concrete examples:\n\n* a clock (using local information) and \n* a weather indicator (collecting data via the internet)\n\n# 4. Fledex: Clock example\nThis is the first \"meaningful\" example that displays the current time on the LED strip. We define 4 \"animations\" for:\n\n* the indicators (otherwise it becomes hard to read the time), \n* the seconds (red), \n* the minutes (green), and \n* the hours (blue).\n\nThis example demonstrates how easy we do things when we can pull the information whenever needed. The current time is something that is readily available on the device and can be called as often as we want. Hence we can call this function every time we paint the strip.\n\n**CAUTION:** we repaint the LED strip very frequent and therefore it's nothing you want to do with data that is expensive to retrieve.\n\n# 5. FLEDex: Weather example\nThis is an example where we **CANNOT** fetch the information every time we want to paint the strip (which could be serveral times per second), since we are calling a public API. The API would surely block us if we would try to attempt to call it that often.\n\nTherefore we fetch the information at regular intervals, outside of our animation loop. For that we define a small GenServer which makes the API call, and publishes the data via pubsub to then be picked up by the animation loop.\n\n# 6. Fledex: DSL\nIn this example we will look at the Fledex DSL that removes a lot of the boilerplate and therefore makes the definition of an LED strip even easier. Under the hood it uses the same principles as the ones we have encountered in the examples 3-5.\n\nIn this example we will reimplement the Clock, but this time with our DSL.","ref":"readme-2.html"},{"type":"extras","title":"1. First steps with an LED strip","doc":"# 1. First steps with an LED strip\n\n```elixir\nMix.install([\n  {:circuits_spi, \"~> 2.0-pre.0\"}\n])\n```","ref":"1_first_steps_with_an_led_strip.html"},{"type":"extras","title":"Search and open the SPI bus - 1. First steps with an LED strip","doc":"First of all we try to figure out what kind of SPI buses exist on the device\n\n```elixir\n_ = Circuits.SPI.bus_names()\n```\n\nAs a next step we open the first SPI bus and close it again. Let's make sure this works without any error\n\n```elixir\n{:ok, ref} =\n  Circuits.SPI.open(\"spidev0.0\",\n    mode: 0,\n    bits_per_word: 8,\n    speed_hz: 1_000_000,\n    delay_us: 10,\n    lsb_first: false\n  )\n\n:ok = Circuits.SPI.close(ref)\n```","ref":"1_first_steps_with_an_led_strip.html#search-and-open-the-spi-bus"},{"type":"extras","title":"Define a data structure - 1. First steps with an LED strip","doc":"Mext we define a data structure as required by the LED strip. The documentation states that we simply\nhave to send the bytes for the different LEDs in a row. If it's too short only a couple of LEDs will be \naddressed and the rest will not get any info. If the data structure is longer all LEDs will receive their\nupdate and the rest of the data will be ignored.\n\nTo start with we define 3 LEDs with the color red\n\n```elixir\nrange = Enum.to_list(1..3)\n\ndata =\n  Enum.reduce(range,  >, fn _index, leds ->\n    leds    >\n  end)\n```","ref":"1_first_steps_with_an_led_strip.html#define-a-data-structure"},{"type":"extras","title":"Send the data to the LED strip - 1. First steps with an LED strip","doc":"For this we need to combine the above steps, i.e.\n\n1. We open the SPI bus\n2. We define a datastructure with only zeros (to delete the strip, make it completely black)\n3. We send the binary to the SPI bus\n4. We define our data structure with some colors (see above)\n5. We send the binary to the SPI bus\n6. We close teh SPI bus\n\nLet's see what the result will be\n\n```elixir\n# 1\n{:ok, ref} =\n  Circuits.SPI.open(\"spidev0.0\",\n    mode: 0,\n    bits_per_word: 8,\n    speed_hz: 1_000_000,\n    delay_us: 10,\n    lsb_first: false\n  )\n\n# 2 (we got a 3m strup with 96 LEDs, 3x 32 LEDs)\ndata_black =\n  Enum.reduce(Enum.to_list(1..96),  >, fn lindex, leds ->\n    leds    >\n  end)\n\n# 3\n{:ok, _} = Circuits.SPI.transfer(ref, data_black)\n\n# 4\ndata_3red =\n  Enum.reduce(Enum.to_list(1..3),  >, fn _index, leds ->\n    leds    >\n  end)\n\n# 5\n{:ok, _} = Circuits.SPI.transfer(ref, data_3red)\n\n# 6\n:ok = Circuits.SPI.close(ref)\n```","ref":"1_first_steps_with_an_led_strip.html#send-the-data-to-the-led-strip"},{"type":"extras","title":"2. Fledex: Some simple tests","doc":"# 2. Fledex: Some simple tests\n\n```elixir\n# We start to define some libraries we need. If you are running on a laptop\n# the libraries will be loaded, but on a nerves_livebook you can only use\n# what has been compiled in.\nMix.install([\n  {:fledex, \"~>0.2\"},\n])\n\n# we define a couple of aliases to not have to type that much\nalias Fledex.Leds\nalias Fledex.LedsDriver\nalias Fledex.LedStripDriver.KinoDriver\nalias Fledex.LedStripDriver.SpiDriver\nalias Fledex.Color.Correction\n\n:ok\n```","ref":"2_fledex_first_steps.html"},{"type":"extras","title":"Section - 2. Fledex: Some simple tests","doc":"Fledex has several drivers which can also be used in parallel. It's probably best to only use\na single driver to start with. The Kino driver does not have any hardware dependency and therefore\nis probably a good start to ensure that the library is loaded correctly.\n\n```elixir\n# frame = Kino.Frame.new() |> Kino.render()\n\n{:ok, pid} =\n  LedsDriver.start_link(%{\n    timer: %{only_dirty_update: false},\n    led_strip: %{\n      merge_strategy: :cap,\n      # [KinoDriver, SpiDriver],\n      driver_modules: [KinoDriver],\n      config: %{\n        KinoDriver => %{\n          update_freq: 1,\n          color_correction: Fledex.Color.Correction.no_color_correction()\n          # frame: frame\n        }\n        #        SpiDriver => %{\n        #          color_correction:\n        #            Correction.define_correction(\n        #              Correction.Color.typical_smd5050(),\n        #              Correction.Temperature.uncorrected_temperature()\n        #            )\n        #        }\n      }\n    }\n  })\n```\n\nWe now define a couple of helper functions. The first 2 functions are talking binaries directly\nwith the LED driver, the latter two are making use of the Leds client module that helps to\ncreate nice effects like a rainbow.\n\n```elixir\ndefmodule Helpers do\n  def red(namespace) do\n    Enum.each(1..10, fn _index ->\n      LedsDriver.set_leds(namespace, [0xFF0000, 0x000000, 0x000000, 0x000000, 0x00000])\n      Process.sleep(600)\n      LedsDriver.set_leds(namespace, [0x000000, 0xFF0000, 0x000000, 0x000000, 0x00000])\n      Process.sleep(600)\n      LedsDriver.set_leds(namespace, [0x000000, 0x000000, 0xFF0000, 0x000000, 0x00000])\n      Process.sleep(600)\n      LedsDriver.set_leds(namespace, [0x000000, 0x000000, 0x000000, 0xFF0000, 0x00000])\n      Process.sleep(600)\n      LedsDriver.set_leds(namespace, [0x000000, 0x000000, 0x000000, 0x000000, 0xFF0000])\n      Process.sleep(600)\n    end)\n  end\n\n  def blue(namespace) do\n    Enum.each(1..10, fn _index ->\n      LedsDriver.set_leds(namespace, [0x000000, 0x000000, 0x000000, 0x000000, 0x0000FF, 0x00FF00])\n      Process.sleep(600)\n      LedsDriver.set_leds(namespace, [0x000000, 0x000000, 0x000000, 0x0000FF, 0x000000, 0x00FF00])\n      Process.sleep(600)\n      LedsDriver.set_leds(namespace, [0x000000, 0x000000, 0x0000FF, 0x000000, 0x000000, 0x00FF00])\n      Process.sleep(600)\n      LedsDriver.set_leds(namespace, [0x000000, 0x0000FF, 0x000000, 0x000000, 0x000000, 0x00FF00])\n      Process.sleep(600)\n      LedsDriver.set_leds(namespace, [0x0000FF, 0x000000, 0x000000, 0x000000, 0x000000, 0x00FF00])\n      Process.sleep(600)\n    end)\n  end\n\n  def rainbow(namespace) do\n    Enum.each(0..10000, fn index ->\n      config = %{\n        num_leds: 50,\n        reversed: true\n      }\n\n      Leds.leds(50)\n      |> Leds.func(:rainbow, config)\n      |> Leds.send(%{namespace: namespace, offset: index})\n\n      # before sending the next update we sleep a bit\n      Process.sleep(100)\n    end)\n  end\n\n  def gradient(namespace) do\n    Enum.each(0..10000, fn index ->\n      config = %{\n        num_leds: 50,\n        start_color: 0xFF0000,\n        end_color: 0x0000FF\n      }\n\n      Leds.leds(50)\n      |> Leds.func(:gradient, config)\n      |> Leds.send(%{namespace: namespace, offset: index, rotate_left: true})\n\n      # before sending the next update we sleep a bit\n      Process.sleep(100)\n    end)\n  end\nend\n```\n\nNow use the above functions. We can run the functions by spawning a new thread. This allows to also see what happens if another thread works in parallel. Here we create a rainbow effect that will be send with an changing offset so that the rainbow rotates through the LEDs\n\n```elixir\nLedsDriver.define_namespace(:default)\nspawn(fn -> Helpers.rainbow(:default) end)\n```\n\nHere we create a gradient between red and blue. Also this one we let rotate through\n\n```elixir\nLedsDriver.define_namespace(:gradient)\nspawn(fn -> Helpers.gradient(:gradient) end)\n```\n\nWe can drop the namespaces to see what happens\n\n```elixir\nLedsDriver.drop_namespace(:john)\nLedsDriver.drop_namespace(:jane)\nLedsDriver.drop_namespace(:default)\nLedsDriver.drop_namespace(:gradient)\n```\n\nThis test is running a couple of different ligth definitions in parallel.\n\n```elixir\nLedsDriver.define_namespace(:john)\nLedsDriver.define_namespace(:jane)\nLedsDriver.define_namespace(:default)\n\nspawn(fn -> Helpers.blue(:jane) end)\nspawn(fn -> Helpers.red(:john) end)\nspawn(fn -> Helpers.rainbow(:default) end)\n```\n\nOnce we are done we should stop our GenServer (even thoguh I rarely run this one ;-))\n\n```elixir\nGenServer.stop(pid)\n```","ref":"2_fledex_first_steps.html#section"},{"type":"extras","title":"3. Fledex: Animations","doc":"# 3. Fledex: Animations\n\n```elixir\n# In this example we'll use the simple setup (experiments are inteded to not run on real\n# hardware but on a normal livebook, This makes it easier to stay up-to-date and experiment\n# We start to define our fledex library, directly linking to the latest version on github\nMix.install([\n  {:fledex, \"~>0.2\"}\n])\n\n# we define a couple of aliases to not have to type that much\nalias Fledex.LedAnimationManager\nalias Fledex.Leds\nalias Fledex.LedsDriver\nalias Fledex.LedStripDriver.KinoDriver\nalias Fledex.Color.Correction\n\n{:ok, pid} = LedAnimationManager.start_link()\n\n:ok\n```","ref":"3_fledex_animations.html"},{"type":"extras","title":"Preparation - 3. Fledex: Animations","doc":"To start with, we define a couple of aliases to make our life easier and more importantly, we start our `LedAnimationManager`. We will use it to create animations. The animations are actually maintained by the LedAnimator, but we will interact with it only through the `LedAnimationManager`.","ref":"3_fledex_animations.html#preparation"},{"type":"extras","title":"Helper functions - 3. Fledex: Animations","doc":"We define a bit of helper functions that we will use when we define our animations. Those helper functions are the actual definitions of how the ledstrip will look.\n\nNote that the functions get in a map (here called triggers) that can contain serveral triggers. It will definitely contain one trigger (caused by the `LedsDriver`) with the name of the led strip. The structure does not need to be used, but can be used in order to change the animation based on the trigger. Here we use the trigger in the send configuration to specify an offset to the leds and thereby create a movement.\n\n```elixir\ndefmodule HelperFunctions do\n  @rainbow Leds.leds(50) |> Leds.func(:rainbow, num_leds: 50, reversed: true)\n  def rainbow(_triggers) do\n    @rainbow\n  end\n\n  def send_config(triggers) do\n    %{offset: triggers[:john]}\n  end\nend\n```","ref":"3_fledex_animations.html#helper-functions"},{"type":"extras","title":"Creating a first animation - 3. Fledex: Animations","doc":"Now it's time to define our first animation by using the `LedAnimationManager`. Before we can define our animations we first have to define (and configure) our led strip. The `LedAnimationManager` can manage serveral strips at the same time.\n\nWe call our led strip `:john` (it has to be an atom). In this example we will only use the simple kino driver (and configure it with defaults) and thereby display the result within our livebook.\n\n```elixir\nLedAnimationManager.register_strip(:john, :kino)\n\nLedAnimationManager.register_animations(:john, %{\n  caine: %{\n    def_func: &HelperFunctions.rainbow/1,\n    send_config_func: &HelperFunctions.send_config/1\n  }\n})\n```","ref":"3_fledex_animations.html#creating-a-first-animation"},{"type":"extras","title":"Replacing our animation - 3. Fledex: Animations","doc":"We can now redefine our animation by regisetering different functions. Here we define a 3 led wide red dot that moves slowly from right to left.\n\n```elixir\nimport Bitwise\n\ndefmodule HelperFunctions2 do\n  @red_leds Leds.leds(50) |> Leds.light(:red) |> Leds.light(:red) |> Leds.light(:red)\n  def red_leds(_triggers) do\n    @red_leds\n  end\n\n  def send_config(triggers) do\n    slow_offset = rem(triggers[:john] >>> 5, 50)\n    %{offset: slow_offset}\n  end\nend\n\nLedAnimationManager.register_animations(:john, %{\n  caine: %{\n    def_func: &HelperFunctions2.red_leds/1,\n    send_config_func: &HelperFunctions2.send_config/1\n  }\n})\n```","ref":"3_fledex_animations.html#replacing-our-animation"},{"type":"extras","title":"Defining serveral animations - 3. Fledex: Animations","doc":"It's also possible to define serveral animations. Here we continue with our previous animation (we do have to explicitly specify it again, otherwise it would be removed) and add a new animation with 3 leds that move faster from right to left.\n\n```elixir\nimport Bitwise\n\ndefmodule HelperFunctions3 do\n  @rgb_leds Leds.leds(50) |> Leds.light(:red) |> Leds.light(:green) |> Leds.light(:blue)\n  def rgb_leds(_triggers) do\n    @rgb_leds\n  end\n\n  def send_config(triggers) do\n    faster_offset = 50 - rem(triggers[:john] >>> 2, 50)\n    %{offset: faster_offset}\n  end\nend\n\nLedAnimationManager.register_animations(:john, %{\n  caine: %{\n    def_func: &HelperFunctions2.red_leds/1,\n    send_config_func: &HelperFunctions2.send_config/1\n  },\n  doe: %{\n    def_func: &HelperFunctions3.rgb_leds/1,\n    send_config_func: &HelperFunctions3.send_config/1\n  }\n})\n```","ref":"3_fledex_animations.html#defining-serveral-animations"},{"type":"extras","title":"Use of anonymous functions - 3. Fledex: Animations","doc":"It is also possible to use an anonymous function during the definition which avoids to create a separate module. Here we redefine our above definition, but this time we define `:doe` with an anonymous function. To really see that we have changed the definition we define the leds  as all blue. In addition we change the `send_config_func` to animate the dots even faster.\n\nThe advantage of using the anonymous functions is that you don't get any compilation error, that occures if you recompile the module. Try it out by reevaluating the below definition several times and then doing the same thing with the previous definition.\n\nThis allows for a smooth replacement of definitions.\n\n```elixir\nLedAnimationManager.register_animations(:john, %{\n  caine: %{\n    def_func: &HelperFunctions2.red_leds/1,\n    send_config_func: &HelperFunctions2.send_config/1\n  },\n  doe: %{\n    def_func: fn _triggers ->\n      Leds.leds(50) |> Leds.light(:blue) |> Leds.light(:blue) |> Leds.light(:blue)\n    end,\n    send_config_func: fn triggers ->\n      faster_offset = 50 - rem(triggers[:john] >>> 1, 50)\n      %{offset: faster_offset}\n    end\n  }\n})\n```\n\nFrom now on we will _only_ define our definitions through the use of anonymous functions.","ref":"3_fledex_animations.html#use-of-anonymous-functions"},{"type":"extras","title":"4. Fledex: Clock Example","doc":"# 4. Fledex: Clock Example\n\n```elixir\nMix.install([\n  {:fledex, \"~>0.2\"}\n])\n\n# we define a couple of aliases to not have to type that much\nalias Fledex.LedAnimationManager\nalias Fledex.Leds\nalias Fledex.LedsDriver\nalias Fledex.LedStripDriver.KinoDriver\nalias Fledex.Color.Correction\n\n{:ok, pid} = LedAnimationManager.start_link()\n\n:ok\n```","ref":"4_fledex_clock_example.html"},{"type":"extras","title":"Intro - 4. Fledex: Clock Example","doc":"The goal of this project is to create a clock that displays its hour, minute and second on the trip. We use the kino driver as output and we limit the amount of leds to a reasonable number.\nTherefore we can't really display every second and every minute. We can get a bit creative in how we display it.\n\nBut before we get there, we first initiate our led strip and ensure that it updates with a very low frequency (transferring updates in high frequency is just a waste of energy)\n\n```elixir\n# we start with the default configuration\n:ok = LedAnimationManager.register_strip(:clock, :kino)\n# and then we modify the timer update frequency to 500ms\n{:ok, _old_value} = LedsDriver.change_config(:clock, [:timer, :update_timeout], 500)\n\n:ok\n```\n\n```elixir\nLedAnimationManager.register_animations(:clock, %{\n  seconds: %{\n    def_func: fn _triggers ->\n      Leds.leds(60) |> Leds.light(:red)\n    end,\n    send_config_func: fn _triggers ->\n      # we work with utc times and adjust, so we don't need to load a timezone library\n      %{hour: _hour, minute: _minute, second: second} = Time.utc_now() |> Time.add(1, :hour)\n      # Logger.info(\"#{second}\")\n      %{offset: second, rotate_left: false}\n    end\n  },\n  minutes: %{\n    def_func: fn _triggers ->\n      Leds.leds(60) |> Leds.light(:green)\n    end,\n    send_config_func: fn _triggers ->\n      # we work with utc times and adjust, so we don't need to load a timezone library\n      %{hour: _hour, minute: minute, second: _second} = Time.utc_now() |> Time.add(1, :hour)\n      # Logger.info(\"#{second}\")\n      %{offset: minute, rotate_left: false}\n    end\n  },\n  hours: %{\n    def_func: fn _triggers ->\n      Leds.leds(60) |> Leds.light(:blue)\n    end,\n    send_config_func: fn _triggers ->\n      # we work with utc times and adjust, so we don't need to load a timezone library\n      %{hour: hour, minute: _minute, second: _second} = Time.utc_now() |> Time.add(1, :hour)\n      # Logger.info(\"#{second}\")\n      %{offset: hour, rotate_left: false}\n    end\n  },\n  help: %{\n    def_func: fn _triggers ->\n      Leds.leds(5)\n      |> Leds.light(:ash_gray)\n      |> Leds.func(:repeat, %{amount: 12})\n    end\n  }\n})\n```","ref":"4_fledex_clock_example.html#intro"},{"type":"extras","title":"5. Fledex: Weather example","doc":"# 5. Fledex: Weather example\n\n```elixir\nMix.install([\n  {:fledex, \"~>0.2\"},\n  {:json, \"~>1.4\"},\n])\n\n# we define a couple of aliases to not have to type that much\nalias Fledex.LedAnimationManager\nalias Fledex.Leds\nalias Fledex.LedsDriver\nalias Fledex.LedStripDriver.KinoDriver\nalias Fledex.Color.Correction\nalias Fledex.Utils.PubSub\n\n{:ok, pid} = LedAnimationManager.start_link()\n\n:ok\n```","ref":"5_fledex_weather_example.html"},{"type":"extras","title":"Intro - 5. Fledex: Weather example","doc":"In the last project we created a clock. We could make a call to get the current time in every redraw loop. This approach is not possible for data that we are fetching from an external source. In this example we will create a weather display. We will get the information from an API.\n\nIf we would take the same approach as in the clock example, we would make an API call every 500ms which probably will result in us getting blocked. It is completely unnecessary to make that many call, since the wheather is not changing that frequently.\n\nWhat we will do is to check every 15 min what the latest weather news is.\n\nThere are plenty of Weather APIs on the internet, but most of them require to register which is not ideal for a public example. Therefore I decided to use [Open-Meteo](https://open-meteo.com/) which provides all we need.\n\nWe need to decide for which location we want to get the weather. We use the coordinate for Budapest (`47.4729344`,`19.0468802`). Then we can make the call [`https://api.open-meteo.com/v1/forecast?latitude=47.4729344&longitude=19.0468802&current=temperature_2m`](https://api.open-meteo.com/v1/forecast?latitude=47.4729344&longitude=19.0468802&current=temperature_2m) to get data like the following:\n\n```json\n{\n  \"latitude\": 47.5,\n  \"longitude\": 19.0625,\n  \"generationtime_ms\": 0.04100799560546875,\n  \"utc_offset_seconds\": 0,\n  \"timezone\": \"GMT\",\n  \"timezone_abbreviation\": \"GMT\",\n  \"elevation\": 113,\n  \"current_units\": {\n    \"time\": \"iso8601\",\n    \"interval\": \"seconds\",\n    \"temperature_2m\": \"°C\"\n  },\n  \"current\": {\n    \"time\": \"2023-10-30T13:30\",\n    \"interval\": 900,\n    \"temperature_2m\": 22.1\n  }\n}\n```\n\nAs can be seen we get the information we are interested in, the current temperature (in °C)","ref":"5_fledex_weather_example.html#intro"},{"type":"extras","title":"Configuring the led strip - 5. Fledex: Weather example","doc":"Now it's time to prepare our led strip. First we define our strip and we set a very low refresh rate. An update every 10 sec is enough.\n\n```elixir\n# we start with the default configuration\n:ok = LedAnimationManager.register_strip(:weather, :kino)\n# and then we modify the timer update frequency to 10 sec\n{:ok, _old_value} = LedsDriver.change_config(:weather, [:timer, :update_timeout], 10_000)\n\n:ok\n```\n\nNow we define two animations, the first one creates blue (below zero), green (zero), or red (above zero) indicators. The indicators have the length of the temperature and start from zero to either go to the left (negative) or the right (positive).\n\nThe temperature will be delivered to us as part of the trigger. We'll look at how we will get  this information in the section below.\n\nAs and additional bonus, the thermometer is showing the full scale, if no proper measurement is received (arbitrarily high value of 100).\n\n```elixir\nLedAnimationManager.register_animations(:weather, %{\n  temperature: %{\n    def_func: fn triggers ->\n      temp = triggers[:temperature] || 100\n      temp = round(temp)\n\n      temp =\n        if temp == 100 do\n          100\n        else\n          temp = min(temp, 40)\n          max(temp, -20)\n        end\n\n      {leds, offset} =\n        case temp do\n          temp when temp == 100 ->\n            {Leds.leds(61)\n             |> Leds.light(:blue, 1, 20)\n             |> Leds.light(:may_green)\n             |> Leds.light(:red, 22, 40), 1}\n\n          temp when temp  \n            {Leds.leds(1) |> Leds.light(:blue) |> Leds.func(:repeat, %{amount: -temp}), 21 + temp}\n\n          temp when temp == 0 ->\n            {Leds.leds(1) |> Leds.light(:may_green), 21}\n\n          temp when temp > 0 ->\n            {Leds.leds(1) |> Leds.light(:red) |> Leds.func(:repeat, %{amount: temp}), 22}\n        end\n\n      Leds.leds(61) |> Leds.light(leds, offset)\n    end\n  },\n  help: %{\n    # we allow temperatures down to -20C and up to +40C\n    def_func: fn _triggers ->\n      negative_scale =\n        Leds.leds(5)\n        |> Leds.light(:ash_gray)\n        |> Leds.func(:repeat, %{amount: 4})\n\n      positive_scale =\n        Leds.leds(5)\n        |> Leds.light(:ash_gray, 5)\n        |> Leds.func(:repeat, %{amount: 8})\n\n      Leds.leds(61)\n      |> Leds.light(negative_scale)\n      |> Leds.light(:ash_gray)\n      |> Leds.light(positive_scale)\n    end\n  }\n})\n```\n\nFor testing we can send an arbitrary temperature value to our strip in the following way. This allows us to also see whether the strip has the correct behavior when the temperature is at zero (or even below) degree. It wouldn't be really practical if we need to wait until the outside temperature reaches those levels.\n\nHere we send a temperature value of -15.2 degree (which the strip should round to 15 degree)\n\n```elixir\nFledex.Utils.PubSub.broadcast(:fledex, \"trigger\", {:trigger, %{temperature: -15.2}})\n```","ref":"5_fledex_weather_example.html#configuring-the-led-strip"},{"type":"extras","title":"Getting the weather data - 5. Fledex: Weather example","doc":"Before we can start with the weather data, we need to make sure that we can make http client calls (also over https) and therefore we start the two services.\n\n```elixir\n:ok = :inets.start()\n:ok = :ssl.start()\n```\n\nNow we can make the actual call. We do want to make this call in regular intervals (every 15 min), parse the response and publish the temperature through pubsub. To do this we create a small server. We start it with our URL (note, the parsing in the server is URL specific, so you can't simply change it to another site) and with our 15min refresh interval (specified in ms).\n\nThe server will extract the temperature and send it via pubsub to our update functions.\n\n```elixir\ndefmodule CallUrlPeriodic do\n  use GenServer\n\n  def start_link(url, interval_ms) do\n    GenServer.start_link(__MODULE__, %{url: url, interval_ms: interval_ms})\n  end\n\n  @impl true\n  def init(state) do\n    :timer.send_interval(state.interval_ms, :work)\n    # we send ourselve immediately a request\n    send(self(), :work)\n    {:ok, state}\n  end\n\n  @impl true\n  def handle_info(:work, state) do\n    {:ok, resp} =\n      :httpc.request(:get, {String.to_charlist(state.url), []}, [], body_format: :binary)\n\n    {{_, 200, ~c\"OK\"}, _headers, body} = resp\n    json = JSON.decode!(body)\n    temperature = json[\"current\"][\"temperature_2m\"]\n    PubSub.broadcast(:fledex, \"trigger\", {:trigger, %{temperature: temperature}})\n\n    {:noreply, state}\n  end\nend\n\n{:ok, pid} =\n  CallUrlPeriodic.start_link(\n    \"https://api.open-meteo.com/v1/forecast?latitude=47.4729344&longitude=19.0468802&current=temperature_2m\",\n    900_000\n  )\n```","ref":"5_fledex_weather_example.html#getting-the-weather-data"},{"type":"extras","title":"6. Fledex: DSL","doc":"# 6. Fledex: DSL\n\n```elixir\n# In this example we'll use the simple setup (experiments are inteded to not run on real\n# hardware but on a normal livebook, This makes it easier to stay up-to-date and experiment\n# We start to define our fledex library, directly linking to the latest version on github\nMix.install([\n  {:fledex, \"~>0.2\"}\n])\n```","ref":"6_fledex_dsl.html"},{"type":"extras","title":"Intro - 6. Fledex: DSL","doc":"We now define our animations with our DSL with the following steps:\n\n* First we have to `use Fledex` in order to import `Fledex`, to load our DSL macros (`led_strip` and `live_loop`), and to import `Fledex.Leds`. This means we won't write `Leds` in fron of functions. By default this will also start the LedAnimationManager if it's not already running which will take care of all the animation coordinations.\n\n```elixir\nuse Fledex\n```\n\n* We define a new strip with a name (`:clock`), and configure it (we use the `:kino` default driver for display). This will internally create a new `LedsDriver` server (if it's not already running) that will control the strip. Its server name will be identical to the `led_strip` name.\n* Then within this strip we define several `live_loop`s that correspond to an animation (and will use internally the `LedAnimator`). Each animaation is identified by its own name (`:help`, `:hour`, `:minute`, `:seconds`)\n* Within each animation we define a function that will repeatedly be executed\n* Inside that function we can define one or several `Leds`, either directly or through an led sequence (like a rainbow function) and animate those leds depending on some trigger data (data that comes into the animation function). An explanation of what we are doing in our example here will be given after the code.\n\nIt is also possble to define some other configurations (like the `send_config_func` as we have done in the \"[Fledex Clock Example](./4_fledex_clock_example.livemd)\") but we will look at this a bit later.\n\n```elixir\nled_strip :clock, :kino do\n  live_loop :nelp do\n    _triggers -> leds(5) |> light(:ash_gray) |> func(:repeat, %{amount: 12})\n  end\n\n  live_loop :hour do\n    _triggers ->\n      %{hour: hour, minute: _minute, second: _second} = Time.utc_now() |> Time.add(1, :hour)\n      leds(24) |> light(:blue, hour + 1)\n  end\n\n  live_loop :minute do\n    _triggers ->\n      %{hour: _hour, minute: minute, second: _second} = Time.utc_now() |> Time.add(1, :hour)\n      leds(60) |> light(:may_green, minute + 1)\n  end\n\n  live_loop :second do\n    _triggers ->\n      %{hour: _hour, minute: _minute, second: second} = Time.utc_now() |> Time.add(1, :hour)\n      leds(60) |> light(:red, second + 1)\n  end\nend\n```\n\nIn our example we first define an \"animation\" (that doesn't really anymate since it's static). It is used to make it easier to read the time by having a dash every 5 steps. This is a repetitive task and therefore we define it only once and then make use of the `:repeat` function (and repeat it 12 times).\n\nFor all other animations we make a call to the system time (`Time.utc_now()`) and therefore don't require the `_trigger` information. We shift the result to the right timezone (we add 1 hour, for UTC+1)\nWe parse the result, depending on the animation into the different aspects of interest (`hour`, `minute`, `second`).\n\nWe then define a sequence of `Leds` of the right length (`24` for `hour`s, and `60` for `minute`s and `second`s). We switch on only a single light in some color at the correct position (with the offset corresponding to `hour`, `minute` or `second`)\n\nNote: in the clock example we defined a static sequence of `Leds` and offsetted it. This requires the definition of a `send_config_func`. We will look on how to do it with the DSL as a next step.","ref":"6_fledex_dsl.html#intro"}],"content_type":"text/markdown"}